︠dd9a787e-7571-4bfe-8863-66da5f368503︠
#The code below is slightly modified from Jane Pitkethly's original Python code
#Modifications by Peter Jipsen, 2012-03-14

# the value of the operation f at the tuple k
# (adjusted for Berman--Burris numbering)
def value(f, k, size):
    kBB = size**2 - 1 - k
    return (f//(size**kBB)) % size

import random    
def Probabilities(size,G="random",steps=300,bits=200,arity="size",dvec="random",abovezero=0.001,tiny=0.00001,ezero=False):
    # This function calculates the sequences beta_{d,H}(a) for a given number of steps.
    # "size" is the number of elements of the groupoid.
    # G is an integer in [0..size^(size^2)] or (by default) the string "random", in which case a random groupoid is used.
    # "bits" is the bits of precision for the floating point numbers (default 200, Python usually is fixed at 53).
    # "arity" is the arity of the terms.
    # "dvec" is a vector of groupoid elements of length arity, or "random". If dvec=[] then dvec=[0,1,...,size-1] is used.
    # "abovezero" is used to determine if a sequence is Good, i.e. if all coordinates are > abovezero, default 0.001
    # "tiny" is used to determine if a sequence converged (last few terms differ be less than tiny).
    # "ezero" is a boolean value, default False, if True then the error term "e" is set to zero. Most sequences converge
    # to the same value or at least have the same behavior either way.
    
    R = RealField(bits)
    if G=="random": G = random.randrange(0,size^(size^2)) # choose a random integer uniformly distributed in the range

    ## create the table for products
    T = [[] for a in range(size)]
    for a in range(size):
        for b in range(size):
            c = value(G, a * size + b,size)
            T[c].append([a,b])

    ## calculate the probability distributions
    if arity=="size": arity = size
    ### initialise vector for current distribution
    if dvec=="random":
        dvec = [random.randrange(0,size) for i in range(arity)] # choose a random d-vector
    if len(dvec)!=arity: dvec = range(size)  # else create the default d-vector [0,1,...,size-1]
    P = [[R(dvec.count(i)/arity)] for i in range(size)]
    ### initialise error
    e = R(0) if ezero else R(1/(arity + 1))
    ### initialise badness flag
    bad = False
    maxperiod = 3
    extra = 103    # minimum number of steps before checking for convergence
    tol = 10^(-10) # tolerance for convergence (= no change in 10 decimal digits)
    ### start iteration
    for h in range(steps):
        ### create new probability vector
        NP = [R(1 - e)*sum(P[t[0]][h]*P[t[1]][h] for t in T[a]) + e*P[a][0] for a in range(size-1)]
        ### smoothing - fix last probability
        NP.append(R(1) - sum(NP))
        ### extend probability vector and check badness
        notdone = False
        for a in range(size):
            P[a].append(NP[a])
            if NP[a] < abovezero and h>size: # avoid initial zeros giving false negative
                bad = True
            if abs(NP[a] - P[a][-2]) > tol:
                notdone = True
        if h>extra and notdone==False: break  # terminates early if all sequences converged
        ### update error
        e = (e*e) / (e*e + R(arity))

    ## check for convergence to small period
    period = 1
    converged = 0 # 0 if not, period 1,2,3 otherwise
    while period <= maxperiod and converged == 0:
        converged = period
        for i in range(len(P[0]) - maxperiod^2,len(P[0]) - period):
            for a in range(size):
                if abs(P[a][i] - P[a][i + period]) > tiny:
                    converged = 0
        period = period + 1
    if len(dvec)==1 and [dvec[0],dvec[0]] in T[dvec[0]]:
        bad = False
        converged = maxperiod+1
    return P,G,bad,converged

def PlotProb(size,G="random",steps=300,bits=200,arity="size",dvec="random",ezero=False):
    # Plots the sequence of probabilities for groupoid G. The other parameters are as for the Probabilities function.
    Ps = Probabilities(size,G,steps,bits,arity,dvec,ezero=ezero)
    st = "Groupoid = "+str(Ps[1])+"\n"
    for k in range(size**2):
        st += repr(value(Ps[1], k, size))+" "
        if (k+1)%size==0: st += "\n"
    print(st+"beta1 = "+str([round(Ps[0][i][0],5) for i in range(size)])+
        "\nbeta"+str(len(Ps[0][0])-1)+" = "+str([round(Ps[0][i][-1],5) for i in range(size)])+
        "\n"+("BAD  " if Ps[2] else "GOOD ")+"period = "+str(Ps[3]))
    col = ["blue","red","green","black","orange","yellow","blue","red","green","black","orange","yellow"]
    return sum(list_plot(Ps[0][i],plotjoined=True,color=col[i],ymin=0,ymax=1,figsize=[10,3]) for i in range(size))

def groupoidtoint(M):
    size = len(M[0])
    v = sum(M,[])  # flatten the list of lists into a single list
    G = 0
    for x in v: G = size*G + x
    return G

# conjugate binary operation f by bijection q
# (i.e., g(q(a),q(b)) = q(f(a,b)) )
def conj(f, q, size):
    g = 0
    for a in range(size):
        for b in range(size):
            k = a * size + b
            l = q[a] * size + q[b]
            lBB = size**2 - 1 - l
            g = g + q[value(f,k,size)] * size**lBB
    return g

def groupoids(size): # works for 2 or 3
    # GROUPOID LIST
    # find one groupoid for each isomorphism class
    B = [[0,1,2],[1,0,2],[0,2,1],[1,2,0],[2,0,1],[2,1,0]]
    L = []
    for f in range(size**(size**2)):
        new = 1
        for q in B[:size*(size-1)]:
            if conj(f, q, size) in L:
                new = 0
        if new == 1:
            L.append(f)
        if f%1000==0: print(f)
    return L

def checkgroupoidlist(size,L,steps=2000,bits=200,arity="size",dvec="random",ezero=False,output=True):
    # This function checks a list L of groupoids (given as integers in [0..size^(size^2)]) and prints some stats
    # It also returns the list of groupoids for each period (0=did not converge), the list of Good groupoids and
    # the list of final coordinates for each groupoid
    nGood = []
    finalP = []
    period = [[],[],[],[],[]]
    if type(L)==sage.rings.integer.Integer: L = ["random" for i in range(L)]
    for n in range(len(L)):
        Ps = Probabilities(size,L[n],steps,bits,arity=arity,dvec=dvec,ezero=ezero)
        if not Ps[2]: nGood.append(L[n])
        period[Ps[3]].append(L[n])
        finalP.append([Ps[0][i][-1] for i in range(size)])
        st = ""
        for k in range(size**2): st += repr(value(Ps[1], k, size))
        if output:
            print(str(n)+" "+str(L[n])+" "+st+(" BAD  " if Ps[2] else " GOOD ")+"period = "+str(Ps[3])+
            " beta1 = "+str([(round(Ps[0][i][0],5) if floor(Ps[0][i][0])!=Ps[0][i][0] else floor(Ps[0][i][0])) for i in range(size)])+
            " beta"+str(len(Ps[0][0])-1)+" = "+str([round(Ps[0][i][-1],5) for i in range(size)]))
    print "Size:", size, " Good:", len(nGood), " Percentage:", round(100*len(nGood)/len(L),2),"%"
    if not output: return period+[nGood]+[finalP]
    print "Not converged", i,":", len(period[0])
    for i in range(1,len(period)-1):
        print "Period", i,":", len(period[i])
    print "Idempotent d", i,":", len(period[0])
    return period+[nGood]+[finalP]

# the following command creates a random 5-element groupoid, starts with d-vector [0,1,2,3,4] 
# and uses 200 bit floating point numbers
PlotProb(5,dvec=[],bits=200)
︡c3bca172-8922-4d53-a774-3b930cc10bcd︡{"stdout": "Groupoid = 82168894791711489\n1 1 4 2 1 \n3 0 0 2 0 \n1 3 3 0 1 \n3 1 3 4 2 \n3 1 4 2 4 \nbeta1 = [0.2, 0.2, 0.2, 0.2, 0.2]\nbeta105 = [0.19292, 0.26737, 0.17168, 0.23899, 0.12904]\nGOOD period = 1"}︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠75b48dd6-b032-4ee0-8337-4e28c5fde1f0︠
for n in range(3,10):
    gl = checkgroupoidlist(n,1000,arity=1,output=False)
︡72b4b880-11c7-4d10-b62f-dfb479090bb9︡{"stdout": "Size: 3  Good: 635  Percentage: 64 %\nSize: 4  Good: 705  Percentage: 71 %\nSize: 5  Good: 785  Percentage: 79 %\nSize: 6  Good: 879  Percentage: 88 %\nSize: 7  Good: 958  Percentage: 96 %\nSize: 8  Good: 969  Percentage: 97 %\nSize: 9  Good: 982  Percentage: 98 %"}︡
︠90f5b356-c25f-4c48-99e2-f7e65c076af0︠
#Here is a command that sets all the available parameters for a specific 3-element groupoid
PlotProb(3,1234,2000,200,3,[0,1,2],False)
︡c5018cdc-c3d2-4edb-8043-603f943a3b93︡{"stdout": "Groupoid = 1234\n0 0 1 \n2 0 0 \n2 0 1 \nbeta1 = [0.33333, 0.33333, 0.33333]\nbeta105 = [0.55496, 0.19806, 0.24698]\nGOOD period = 1"}︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠5ab49803-9c8f-48e4-b836-cd457533a062︠
#Here is the same command with parameters named explicitly (then the order does not matter, and some can be left out)
PlotProb(3, G=1234, steps=2000, bits=200, arity=3, dvec=[0,1,2], ezero=False)
︡932132f5-fd98-43b2-ac8f-c62aa75c2c6b︡{"stdout": "Groupoid = 1234\n0 0 1 \n2 0 0 \n2 0 1 \nbeta1 = [0.33333, 0.33333, 0.33333]\nbeta105 = [0.55496, 0.19806, 0.24698]\nGOOD period = 1"}︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠4ba0884b-ae20-4196-96f7-d1a32c49d3b8︠
# This command check a random list of 200 4-element groupoids and reports statistics.
# The numbers for the groupoids that were generated, and the final values of their beta-sequences is returned in L.
# L[i] for i=0,1,2,3 are the groupoids with period i, where i=0 means "did not converge (yet?)"
# L[4] is the list of Good groupoids
# L[5] is the list of all final beta-sequence values

L=checkgroupoidlist(4,200,arity=1)
︡d3cff262-949f-4d25-988e-459dc34aae9d︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/4/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 0213021320332220 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.22222, 0.11111, 0.33333, 0.33333]\n1 random 0011320032113100 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.46899, 0.21995, 0.06202, 0.24904]\n2 random 3220012012220210 BAD  period = 2 beta1 = [1, 0, 0, 0] beta2000 = [1.0, 0.0, 0.0, 0.0]\n3 random 0123233020122112 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.18479, 0.28312, 0.32195, 0.21014]\n4 random 2232100312023222 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.25686, 0.14472, 0.41871, 0.17972]\n5 random 2132021002100030 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.34991, 0.22425, 0.28581, 0.14003]\n6 random 2312112112020132 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n7 random 2002103012203211 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.0, 0.0, 1.0, 0.0]\n8 random 2030321001121303 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 1.0]\n9 random 2102122110223130 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.25, 0.25, 0.5, 0.0]\n10 random 1230302133302300 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.33933, 0.16549, 0.19098, 0.30419]\n11 random 3000001003031103 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 1.0]\n12 random 3010223333131012 GOOD period = 1 beta1 = [1, 0, 0, 0] beta224 = [0.19589, 0.23692, 0.22182, 0.34537]\n13 random 3000020112301223 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.39221, 0.20636, 0.16439, 0.23704]\n14 random 0132002003112212 GOOD period = 1 beta1 = [0, 0, 1, 0] beta116 = [0.45764, 0.19164, 0.21265, 0.13807]\n15 random 3120133030033032 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.19098, 0.0, 0.30902, 0.5]\n16 random 1230323330023212 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.21282, 0.14752, 0.31149, 0.32818]\n17 random 0321303023331131 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.36603, 0.36603, 0.0, 0.26795]\n18 random 1012003220030301 BAD  period = 2 beta1 = [1, 0, 0, 0] beta2000 = [1.0, 0.0, 0.0, -0.0]\n19 random 3102232110310213 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.16815, 0.3124, 0.25866, 0.26078]\n20 random 0102033001021010 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n21 random 0013323200123100 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.5, 0.0, 0.0, 0.5]\n22 random 2011330120222210 GOOD period = 1 beta1 = [0, 0, 0, 1] beta113 = [0.23958, 0.19238, 0.48495, 0.0831]\n23 random 1111213103122033 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.12288, 0.57135, 0.11556, 0.19021]\n24 random 0221222233211112 BAD  period = 1 beta1 = [0, 0, 0, 1] beta253 = [0.0, 0.20678, 0.6573, 0.13592]\n25 random 1202312113112131 BAD  period = 1 beta1 = [0, 0, 1, 0] beta2000 = [0.0, 0.9995, 0.00025, 0.00025]\n26 random 0300023131113100 BAD  period = 1 beta1 = [0, 0, 1, 0] beta2000 = [0.9995, 0.0, 0.0, 0.0005]\n27 random 2012300103213022 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.0, 0.0, 1.0, 0.0]\n28 random 3321203023120131 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.21791, 0.27425, 0.21791, 0.28994]\n29 random 0201311332031312 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.07955, 0.32242, 0.23373, 0.36431]\n30 random 3331020002320031 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.38742, 0.21248, 0.09381, 0.30629]\n31 random 2231201120100102 GOOD period = 1 beta1 = [1, 0, 0, 0] beta125 = [0.27449, 0.29423, 0.33839, 0.09289]\n32 random 1212002100232230 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.0, 0.0, 1.0, 0.0]\n33 random 1132100110020122 BAD  period = 2 beta1 = [0, 0, 0, 1] beta2000 = [0.0, 1.0, 0.0, 0.0]\n34 random 2302032010031113 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.2927, 0.24832, 0.21067, 0.24832]\n35 random 1222022330210223 BAD  period = 1 beta1 = [0, 1, 0, 0] beta2000 = [0.00037, 0.00037, 0.99888, 0.00037]\n36 random 2303122103110110 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.14404, 0.38697, 0.27812, 0.19086]\n37 random 3222131212110320 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0634, 0.36895, 0.34556, 0.22208]\n38 random 2010022110111223 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.33333, 0.33333, 0.33333, -0.0]\n39 random 2100010033320000 BAD  period = 1 beta1 = [0, 0, 1, 0] beta134 = [0.47726, 0.0, 0.29496, 0.22778]\n40 random 1311331220213130 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.16667, 0.33333, 0.16667, 0.33333]\n41 random 1113213123133012 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.1155, 0.55492, 0.12144, 0.20814]\n42 random 3100302310132301 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.26766, 0.24531, 0.12751, 0.35953]\n43 random 1232122301301001 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.23359, 0.28884, 0.2778, 0.19977]\n44 random 0301120120311322 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.28114, 0.29229, 0.23345, 0.19312]\n45 random 3313230112211122 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.12526, 0.27849, 0.44978, 0.14648]\n46 random 1000000120010302 BAD  period = 2 beta1 = [1, 0, 0, 0] beta2000 = [1.0, 0.0, 0.0, 0.0]\n47 random 0031012231330032 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n48 random 3133301010330100 BAD  period = 2 beta1 = [1, 0, 0, 0] beta2000 = [0.57755, 0.0, 0.0, 0.42245]\n49 random 1232022033111323 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.11086, 0.24503, 0.30254, 0.34158]\n50 random 3013332211000023 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 1.0]\n51 random 2003230202322313 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.17829, 0.12191, 0.32718, 0.37261]\n52 random 0011312123202002 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n53 random 1110110011312021 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0, 1.0, 0.0, 0.0]\n54 random 0223111101000213 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n55 random 1312001330022222 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.27702, 0.22977, 0.30197, 0.19124]\n56 random 1200113113112203 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n57 random 2232100123320100 BAD  period = 1 beta1 = [0, 0, 0, 1] beta125 = [0.29289, 0.0, 0.41421, 0.29289]\n58 random 2030123120232131 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.17082, 0.27639, 0.27639, 0.27639]\n\n...\n\n145 random 3210103331002112 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.24486, 0.31136, 0.19732, 0.24645]\n146 random 3000132302132111 BAD  period = 2 beta1 = [0, 0, 0, 1] beta2000 = [0.0, 0.42245, 0.0, 0.57755]\n147 random 3311212213222133 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 1.0]\n148 random 3203210110333032 BAD  period = 2 beta1 = [0, 0, 1, 0] beta2000 = [0.0, 0.0, 0.0, 1.0]\n149 random 2300220133313232 GOOD period = 1 beta1 = [0, 0, 0, 1] beta168 = [0.15506, 0.17643, 0.29133, 0.37718]\n150 random 3010301201130221 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.37864, 0.21013, 0.14921, 0.26202]\n151 random 2133113022210110 GOOD period = 1 beta1 = [0, 0, 0, 1] beta2000 = [0.00928, 0.97189, 0.00946, 0.00937]\n152 random 0022030032032301 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n153 random 2100211311202132 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.0, 0.0, 1.0, 0.0]\n154 random 2221130210021020 BAD  period = 2 beta1 = [0, 1, 0, 0] beta2000 = [1.0, 0.0, 0.0, 0.0]\n155 random 1002033013120230 GOOD period = 1 beta1 = [0, 0, 0, 1] beta132 = [0.43069, 0.26441, 0.13863, 0.16627]\n156 random 2232023201022010 GOOD period = 1 beta1 = [1, 0, 0, 0] beta258 = [0.35436, 0.10163, 0.37363, 0.17037]\n157 random 2030301013202230 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.3124, 0.13442, 0.30085, 0.25233]\n158 random 0111331333120111 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n159 random 0001230212122322 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n160 random 2313103113310332 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.12633, 0.27205, 0.18748, 0.41415]\n161 random 0002111113032323 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n162 random 3002120021133213 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.25, 0.25, 0.25, 0.25]\n163 random 2022030130011101 GOOD period = 1 beta1 = [0, 0, 1, 0] beta178 = [0.37431, 0.16979, 0.31075, 0.14515]\n164 random 1101111222030211 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n165 random 3122011201321302 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n166 random 1110330011010111 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.29289, 0.41421, 0.0, 0.29289]\n167 random 3332223231031300 GOOD period = 1 beta1 = [1, 0, 0, 0] beta106 = [0.27272, 0.13277, 0.20982, 0.38468]\n168 random 0122300121213321 GOOD period = 0 beta1 = [0, 0, 0, 1] beta2000 = [0.05487, 0.05506, 0.88667, 0.0034]\n169 random 0123221102210031 BAD  period = 1 beta1 = [0, 1, 0, 0] beta2000 = [0.0, 0.0005, 0.9995, -0.0]\n170 random 0032033122231332 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.0, 0.0, 1.0, 0.0]\n171 random 1231323232031003 GOOD period = 1 beta1 = [0, 1, 0, 0] beta164 = [0.2, 0.2, 0.2, 0.4]\n172 random 0222303123321200 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.24127, 0.08522, 0.41249, 0.26102]\n173 random 0103133231332230 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.41421, 0.0, 0.17157, 0.41421]\n174 random 1233120120031221 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.25417, 0.25417, 0.31043, 0.18122]\n175 random 1322023322120101 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.14339, 0.26656, 0.39454, 0.19551]\n176 random 2033213313221311 BAD  period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.0, 0.5, 0.0, 0.5]\n177 random 3002221032232321 BAD  period = 1 beta1 = [0, 1, 0, 0] beta2000 = [-0.0, 0.0005, 0.9995, -0.0]\n178 random 0030002122222111 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n179 random 3222200101013301 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.31749, 0.19622, 0.27899, 0.20729]\n180 random 2021110301122211 BAD  period = 0 beta1 = [0, 0, 1, 0] beta2000 = [0.05483, 0.94199, 0.00318, -0.0]\n181 random 0003103222322200 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n182 random 1100333132301230 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.24698, 0.30798, 0.13706, 0.30798]\n183 random 2120112330210020 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0]\n184 random 1211131200130120 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.2, 0.4, 0.2, 0.2]\n185 random 0120021112323023 BAD  period = 1 beta1 = [1, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0]\n186 random 2022101101111132 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.38197, 0.38197, 0.23607, 0.0]\n187 random 0021332202123123 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.0, 0.33333, 0.53934, 0.12732]\n188 random 1213211300103030 BAD  period = 1 beta1 = [1, 0, 0, 0] beta264 = [0.16374, 0.62996, 0.2063, -0.0]\n189 random 0320031012011202 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.48728, 0.20634, 0.16325, 0.14312]\n190 random 1111101231333203 BAD  period = 0 beta1 = [0, 1, 0, 0] beta438 = [NaN, NaN, NaN, NaN]\n191 random 2123223200112220 GOOD period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.20439, 0.2652, 0.39781, 0.1326]\n192 random 2031311230122000 GOOD period = 1 beta1 = [1, 0, 0, 0] beta105 = [0.28648, 0.24812, 0.25069, 0.21472]\n193 random 1000211300230330 GOOD period = 1 beta1 = [0, 0, 0, 1] beta105 = [0.40959, 0.33552, 0.16448, 0.09041]\n194 random 3010300303013113 BAD  period = 1 beta1 = [1, 0, 0, 0] beta2000 = [0.0005, 0.0, 0.0, 0.9995]\n195 random 3303002022321020 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.25308, 0.07543, 0.37346, 0.29804]\n196 random 3303021220200130 BAD  period = 2 beta1 = [0, 1, 0, 0] beta2000 = [0.49991, 0.0, 0.0, 0.50009]\n197 random 2010033003303102 GOOD period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.42598, 0.12523, 0.22953, 0.21926]\n198 random 3333002201212013 BAD  period = 1 beta1 = [0, 0, 1, 0] beta105 = [0.0, 0.0, 1.0, 0.0]\n199 random 1133032002323320 BAD  period = 1 beta1 = [0, 1, 0, 0] beta105 = [0.3569, 0.19806, 0.0, 0.44504]\nGood: 95  Percentage: 48 %\nPeriod 0 : 6\nPeriod 1 : 176\nPeriod 2 : 18\nPeriod 3 : 0"}︡
︠e883be97-12f9-4e68-b692-2766db356476︠
L=checkgroupoidlist(5,200,arity=1)
︡1e23c4aa-0291-4f90-98ba-b2d95e622533︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/12/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 1011203442333304341311331 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.02658, 0.29584, 0.05915, 0.43496, 0.18347]\n1 random 1033110243112212300230044 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0]\n2 random 3104000114444243311410042 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.284, 0.23016, 0.07304, 0.16601, 0.2468]\n3 random 4101002431223233303214124 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0]\n4 random 2204200414301313423342423 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0747, 0.13858, 0.21166, 0.38228, 0.19278]\n5 random 4144302104330323323234233 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta2000 = [0.00025, 0.0, 0.01595, 0.98354, 0.00025]\n6 random 4112404130122134223213141 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.04862, 0.29254, 0.3973, 0.14395, 0.11759]\n7 random 0241300141220420101142110 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.33243, 0.17254, 0.26762, 0.05674, 0.17068]\n8 random 0430112112133411334033414 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0]\n9 random 3320304011341323120111002 BAD  period = 2 beta1 = [1, 0, 0, 0, 0] beta2000 = [0.57755, -0.0, 0.0, 0.42245, -0.0]\n10 random 1130444220014322323140210 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta1822 = [0.36299, 0.20685, 0.0, 0.0, 0.43016]\n11 random 2221412433344241304231212 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta2000 = [0.00023, 0.00045, 0.49944, 0.00045, 0.49944]\n12 random 2341130412302122302124030 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.19972, 0.18207, 0.29076, 0.19173, 0.13572]\n13 random 4211123210414434324403413 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta271 = [0.09193, 0.23765, 0.094, 0.29749, 0.27894]\n14 random 2322302300320234122333242 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.24785, 0.0, 0.49784, 0.19447, 0.05984]\n15 random 1330301121222332312244044 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0]\n16 random 0313330043034224123431231 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.05307, 0.22417, 0.0, 0.47347, 0.2493]\n17 random 4011044323311010431304201 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta191 = [0.38125, 0.17333, 0.02649, 0.10484, 0.31409]\n18 random 3310333001433231420324030 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.31087, 0.15166, 0.09655, 0.34403, 0.09688]\n19 random 2242201044022203401204310 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.31856, 0.02178, 0.42393, 0.0904, 0.14532]\n20 random 1133344033302331033301312 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0]\n21 random 4002014403310431331040020 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta236 = [0.40304, 0.10177, 0.07516, 0.1046, 0.31544]\n22 random 4331112422343033224313413 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.07346, 0.14433, 0.22267, 0.3299, 0.22964]\n23 random 0214131412001401223244022 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0]\n24 random 4431322031042142441224440 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0]\n25 random 0033421131224443243430410 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0]\n26 random 1220020141413044344214322 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.13718, 0.21045, 0.23869, 0.15143, 0.26225]\n27 random 2041143100413242113420211 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.21346, 0.29196, 0.17003, 0.13142, 0.19313]\n28 random 0422043322310143224330234 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.15966, 0.10444, 0.28974, 0.25602, 0.19014]\n29 random 2302122434141311123241002 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.11419, 0.2934, 0.25125, 0.09228, 0.24888]\n30 random 2303001400333422304323124 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0]\n31 random 2443214340000444340443233 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.14622, 0.0, 0.12939, 0.3325, 0.39189]\n32 random 1210214333230211143042421 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.12387, 0.22732, 0.21499, 0.26839, 0.16543]\n33 random 2303040401311320001432012 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.33022, 0.15668, 0.15076, 0.26044, 0.1019]\n34 random 0323124013444431423011020 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.1981, 0.22251, 0.15201, 0.21158, 0.2158]\n35 random 3040131321330003304213223 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.26297, 0.10474, 0.15514, 0.32846, 0.14868]\n36 random 2230231102310424003231023 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.27225, 0.0, 0.25984, 0.3054, 0.1625]\n37 random 3003222040334304031440000 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.30258, 0.07098, 0.10398, 0.26643, 0.25602]\n38 random 2300131121423210403012440 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.21103, 0.2419, 0.2162, 0.18194, 0.14893]\n39 random 1324300343233040321210344 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0]\n40 random 4211321400131234242244122 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.09824, 0.26844, 0.26733, 0.15053, 0.21545]\n41 random 4220401104244310011241022 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta145 = [0.07884, 0.5, 0.14039, 0.0, 0.28078]\n42 random 1234423104031442441001412 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.13718, 0.22413, 0.18815, 0.11822, 0.33232]\n43 random 2102433142144304013431100 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.20839, 0.21129, 0.13657, 0.21025, 0.2335]\n44 random 0101412112310421302110442 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.17173, 0.46126, 0.24849, 0.07921, 0.03932]\n45 random 2300441030011132034124301 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.28273, 0.19279, 0.17792, 0.18051, 0.16605]\n46 random 1123010143341424411440423 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.14402, 0.1906, 0.12917, 0.21439, 0.32183]\n47 random 2200143401234203123001221 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0]\n48 random 1403141034414242104203230 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.20979, 0.20979, 0.14485, 0.17314, 0.26244]\n49 random 2233120330331103312420001 BAD  period = 3 beta1 = [0, 0, 0, 0, 1] beta2000 = [0.0, 0.0, 1.0, 0.0, 0.0]\n50 random 0022320131042011212423014 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0]\n51 random 0104313030331211100113123 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.19911, 0.37817, 0.03147, 0.32629, 0.06497]\n52 random 1100040340040003233110203 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.37559, 0.34775, 0.03195, 0.07642, 0.1683]\n53 random 0132242323024001320431122 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0]\n54 random 2100211212212444334130221 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta2000 = [0.00026, 0.4902, 0.50904, 0.00025, 0.00026]\n55 random 0442242413322312243000434 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0]\n56 random 0210400422312042131042232 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0]\n57 random 2401020413421431431334112 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.11967, 0.26947, 0.14684, 0.21764, 0.24638]\n58 random 0244322133311421332200032 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0]\n\n...\n\n145 random 1010342003101102003020124 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0]\n146 random 3433004014212332140131031 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta2000 = [0.01185, 0.49103, 0.00014, 0.01185, 0.48513]\n147 random 1032042000010440213021422 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.36857, 0.22415, 0.18311, 0.07279, 0.15138]\n148 random 2222133321123032024211101 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.15329, 0.1294, 0.38622, 0.26229, 0.0688]\n149 random 4303144224422412344301324 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.0, 0.15625, 0.25909, 0.20847, 0.3762]\n150 random 4012212222131014413011202 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta129 = [0.1025, 0.33608, 0.35302, 0.13757, 0.07084]\n151 random 1240304223443423022103010 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.24175, 0.13849, 0.21965, 0.20031, 0.1998]\n152 random 2331042140003413143233300 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.19704, 0.16525, 0.12498, 0.33929, 0.17344]\n153 random 4343424021322033004001102 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.29127, 0.07536, 0.13728, 0.23442, 0.26167]\n154 random 3320244013124240300122120 BAD  period = 0 beta1 = [0, 0, 0, 1, 0] beta428 = [NaN, NaN, NaN, NaN, NaN]\n155 random 0234402433212231444313214 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.14624, 0.14624, 0.33676, 0.37075]\n156 random 3001102120210233413420413 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.27876, 0.23449, 0.22446, 0.18751, 0.07478]\n157 random 1232234234211232312233121 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.31616, 0.29479, 0.24288, 0.14617]\n158 random 1300400443400211210242344 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.1436, 0.13025, 0.15689, 0.14152, 0.42774]\n159 random 0100110313223233002202104 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.5, 0.5, -0.0, -0.0, 0.0]\n160 random 3412023011112444144234314 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0]\n161 random 1013140143000002413041310 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.29786, 0.28864, 0.04089, 0.13728, 0.23532]\n162 random 3401344424233410202020303 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.2759, 0.10249, 0.21527, 0.24765, 0.15869]\n163 random 3432013220413343312403214 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0]\n164 random 2211040344424000144022302 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.25454, 0.1083, 0.28029, 0.10184, 0.25504]\n165 random 2334431401302331433402230 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0]\n166 random 0023214021140433131434142 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0]\n167 random 2440211422112434012130302 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0]\n168 random 4022423311101323211003034 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.12773, 0.33708, 0.21467, 0.30139, 0.01912]\n169 random 1403120312133420413241211 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.13813, 0.2858, 0.18704, 0.22163, 0.1674]\n170 random 3414122320430402212332300 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.20282, 0.14194, 0.24174, 0.23237, 0.18112]\n171 random 0123231011204321322014414 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0]\n172 random 0140222313320324203433401 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.27192, 0.09193, 0.1623, 0.26826, 0.2056]\n173 random 1331104002004013341420310 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta344 = [0.27648, 0.27824, 0.07325, 0.23997, 0.13205]\n174 random 3141102441222344441120103 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.12468, 0.24947, 0.25518, 0.11123, 0.25943]\n175 random 3233442120023221432214222 BAD  period = 2 beta1 = [0, 0, 1, 0, 0] beta2000 = [0.0, 0.0, 0.57755, 0.42245, 0.0]\n176 random 1040142012414322311031202 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta108 = [0.15376, 0.23022, 0.31139, 0.07652, 0.22812]\n177 random 3400340221011431401201123 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.24621, 0.24966, 0.14332, 0.17077, 0.19004]\n178 random 1132340122040112241420003 GOOD period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.25516, 0.25594, 0.20609, 0.12041, 0.16242]\n179 random 4022422404043034302302400 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta2000 = [0.4995, 0.0, 0.0005, 0.0005, 0.4995]\n180 random 3433202304002222012210333 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.20801, 0.10652, 0.4184, 0.24227, 0.0248]\n181 random 4430244134202421111232422 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0]\n182 random 1042421330341142332012043 GOOD period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.15346, 0.18654, 0.21074, 0.25907, 0.19019]\n183 random 1040311221422334431401000 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0]\n184 random 0141121122244132321114213 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.36552, 0.23906, 0.16762, 0.2278]\n185 random 4300300100342033034233203 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.27076, 0.0, 0.12822, 0.38187, 0.21914]\n186 random 1324210103231312413113313 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.16087, 0.2718, 0.10876, 0.32007, 0.13849]\n187 random 3203342313020302030421231 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.36766, 0.0, 0.16999, 0.46235, 0.0]\n188 random 2301100434033413443322242 BAD  period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0]\n189 random 2202232242034124311202024 BAD  period = 1 beta1 = [1, 0, 0, 0, 0] beta105 = [0.48086, 0.0, 0.36299, 0.0, 0.15614]\n190 random 3121342204001423100431322 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.21839, 0.21263, 0.22967, 0.1891, 0.15021]\n191 random 1203434323400230324233411 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.16712, 0.12656, 0.23324, 0.26461, 0.20848]\n192 random 0201442032141441321111420 BAD  period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.2576, 0.24092, 0.19414, 0.0, 0.30734]\n193 random 2123000302320132341001330 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.24198, 0.19185, 0.23807, 0.26501, 0.06309]\n194 random 0001404030033210101101210 BAD  period = 1 beta1 = [0, 0, 1, 0, 0] beta2000 = [0.9995, 0.0, 0.0, 0.0, 0.0005]\n195 random 0323311102230441434001202 GOOD period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.23431, 0.23431, 0.16166, 0.21401, 0.15571]\n196 random 1410313302041443003402224 GOOD period = 1 beta1 = [0, 1, 0, 0, 0] beta105 = [0.23689, 0.16088, 0.16561, 0.19334, 0.24329]\n197 random 1140342201313314121140111 GOOD period = 1 beta1 = [0, 0, 0, 1, 0] beta105 = [0.10992, 0.36175, 0.27249, 0.15801, 0.09784]\n198 random 0303221222323333400423212 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta105 = [0.5, 0.0, 0.0, 0.5, 0.0]\n199 random 0424433304203222333314230 BAD  period = 1 beta1 = [0, 0, 0, 0, 1] beta2000 = [0.0, 0.0, 0.0005, 0.9995, 0.0]\nGood: 113  Percentage: 57 %\nPeriod 0 : 3\nPeriod 1 : 193\nPeriod 2 : 3\nPeriod 3 : 1"}︡
︠6db41b42-969b-476b-b881-c26b672cba4c︠
L=checkgroupoidlist(6,200,arity=1)
︡88c5996a-719a-4b1c-a797-4b3af0e5fa6d︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/13/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 320313035152232155154435032553522212 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n1 random 023504034303332155005321320225415051 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n2 random 524555344314321455510331402240434425 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n3 random 142215003551522024544401214231035524 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.09389, 0.12111, 0.31916, 0.10074, 0.2073, 0.15781]\n4 random 020233315144045305555314105340504150 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n5 random 102112005014410251331421110323130440 BAD  period = 2 beta1 = [0, 0, 1, 0, 0, 0] beta2000 = [0.99928, 0.00016, 0.0, 0.00039, 0.0, 0.00016]\n6 random 303554505400434453432013524112241224 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.12276, 0.15237, 0.18318, 0.14025, 0.23631, 0.16514]\n7 random 155011454223024410544154253103103554 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.14181, 0.1815, 0.10835, 0.13584, 0.19805, 0.23444]\n8 random 103035540424140041305103303534255104 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.23835, 0.16237, 0.06456, 0.21283, 0.16009, 0.16179]\n9 random 343501050210405144235535452033311513 BAD  period = 2 beta1 = [0, 0, 0, 0, 0, 1] beta2000 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n10 random 421305511523155211324422414330111240 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.03661, 0.51399, 0.14172, 0.09962, 0.0389, 0.16915]\n11 random 550320543435105011003251250415005242 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.36426, 0.11089, 0.13761, 0.03633, 0.02557, 0.32534]\n12 random 451345150132252551414350015215023013 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.15623, 0.20571, 0.15967, 0.15863, 0.08832, 0.23144]\n13 random 152323341500214120410300501442240001 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n14 random 450404121031340433310045441540132003 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta2000 = [0.0005, -0.0, 0.0, -0.0, 0.9995, 0.0]\n15 random 504230452533000433001015511042501135 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta133 = [0.2415, 0.08219, 0.04473, 0.09497, 0.03621, 0.50038]\n16 random 011504150002005421322530140335110320 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.27513, 0.37761, 0.08945, 0.01428, 0.07608, 0.16746]\n17 random 542141220531500311303015343443044235 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n18 random 155231525445224400112052431505034305 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.1806, 0.14133, 0.13547, 0.11848, 0.13349, 0.29063]\n19 random 133144415523111331434145352440554445 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta2000 = [0.00043, 0.00043, 0.01419, 0.0144, 0.9701, 0.00044]\n20 random 122254220320341110133555401431103522 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.14741, 0.21576, 0.21961, 0.1971, 0.09943, 0.12068]\n21 random 141350351135122001315524125553012354 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.08003, 0.24644, 0.14063, 0.145, 0.12617, 0.26173]\n22 random 321022434544020321541100145334311133 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.13543, 0.19323, 0.11933, 0.2292, 0.2211, 0.10171]\n23 random 521212453115224021233333014022421540 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.12197, 0.16141, 0.22631, 0.2995, 0.11489, 0.07592]\n24 random 503551355030450452412223041304114405 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.2135, 0.17628, 0.06803, 0.13823, 0.17149, 0.23248]\n25 random 000145301142120010514312355412234324 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.25337, 0.22214, 0.12852, 0.15539, 0.12782, 0.11276]\n26 random 400313313001300423223123011413055520 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.2681, 0.20121, 0.16188, 0.22792, 0.14089, -0.0]\n27 random 340344003414545114012150043254141503 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.22734, 0.13762, 0.04366, 0.1259, 0.30314, 0.16233]\n28 random 351240320202234242311301344325144554 BAD  period = 2 beta1 = [0, 0, 1, 0, 0, 0] beta2000 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n29 random 214053454253225322333503523230142402 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.10893, 0.02354, 0.2443, 0.328, 0.10263, 0.1926]\n30 random 133453135052042511302000434341111352 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.25912, 0.18285, 0.03871, 0.28145, 0.1431, 0.09478]\n31 random 305130104105235532420000120122405145 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.26802, 0.18688, 0.13734, 0.14608, 0.11983, 0.14185]\n32 random 210255252150013352414531253303535151 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.11072, 0.30478, 0.14937, 0.14694, 0.03822, 0.24997]\n33 random 231535352315403204125242333020405402 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.15743, 0.08186, 0.23322, 0.20076, 0.16535, 0.16138]\n34 random 022132120154541242240313051521515111 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.09965, 0.29057, 0.23425, 0.0211, 0.16774, 0.1867]\n35 random 033030131340350052210345410321320110 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta399 = [0.53216, 0.04461, 0.14502, 0.26936, 0.0, 0.00885]\n36 random 505503252520335502331105134321133241 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.07599, 0.21121, 0.1747, 0.2543, 0.0, 0.28381]\n37 random 535234131033424324531132035044200215 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n38 random 105144422024310545525002121452423435 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.10973, 0.11656, 0.20651, 0.12071, 0.21251, 0.23399]\n39 random 555125504222503233533412024550223325 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.05469, 0.0676, 0.23671, 0.32097, 0.15593, 0.1641]\n40 random 424300333114512133434450501255013412 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.13898, 0.20411, 0.10195, 0.21414, 0.19283, 0.14798]\n41 random 532030222442010005102334304224204210 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.32184, 0.06967, 0.2468, 0.11745, 0.10673, 0.13752]\n42 random 152520242151255014322452134434023500 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.15512, 0.13046, 0.24191, 0.11389, 0.16788, 0.19073]\n43 random 342032054242521213213430520415203052 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.14437, 0.15627, 0.26673, 0.17467, 0.14163, 0.11633]\n44 random 104430425130403203530444114503014540 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.2174, 0.20818, 0.0524, 0.17286, 0.24031, 0.10885]\n45 random 041041401133225533212535545340425043 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.15668, 0.10875, 0.10961, 0.21876, 0.20147, 0.20472]\n46 random 300210233502130250314300221225313234 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n47 random 432533350344524442123333404555315210 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n48 random 401152523505301400131340234213040535 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n49 random 034142032421215535302541554110153301 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.14283, 0.23547, 0.12607, 0.19071, 0.11642, 0.1885]\n50 random 434255513425334134430525234552243013 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.09165, 0.09013, 0.1631, 0.22208, 0.18345, 0.24959]\n51 random 520234334423304033021320553114102131 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.19873, 0.14309, 0.18544, 0.26481, 0.12553, 0.0824]\n52 random 311355051222025410300245230343530504 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.19351, 0.06005, 0.1205, 0.21674, 0.14832, 0.26088]\n53 random 402314433521002301514114344243032210 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n54 random 450051515124031240341341321503024505 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.20349, 0.16946, 0.10775, 0.13316, 0.16502, 0.22112]\n55 random 321003242452544152111301303502435453 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.14114, 0.17289, 0.16103, 0.18694, 0.17083, 0.16718]\n56 random 422522244325010204244051350511541033 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta199 = [0.23334, 0.12619, 0.25357, 0.08846, 0.18068, 0.11774]\n57 random 353124000100043124452053424220255302 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.19644, 0.09588, 0.23919, 0.18039, 0.18387, 0.10422]\n58 random 105105201442124002540531330453051131 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.2433, 0.23904, 0.15918, 0.09451, 0.10582, 0.15813]\n\n...\n\n145 random 145253432121350043323140132151211201 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.12363, 0.24147, 0.21231, 0.21664, 0.10456, 0.10138]\n146 random 431541152001414245024244101240121553 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta131 = [0.17573, 0.27741, 0.12326, 0.07082, 0.2042, 0.14858]\n147 random 253210505343310512225014311403345354 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.14344, 0.14979, 0.14294, 0.22035, 0.16058, 0.18289]\n148 random 540244323550520512541144145243515340 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.05722, 0.11127, 0.09519, 0.1085, 0.46944, 0.15839]\n149 random 440422323041330122241500230253050320 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.25956, 0.09113, 0.25066, 0.17047, 0.16592, 0.06226]\n150 random 050344010540340404050453511540303154 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.19985, 0.04942, 0.0, 0.10422, 0.37225, 0.27426]\n151 random 401000544234033024153245322411321411 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.18601, 0.16157, 0.18679, 0.18524, 0.20677, 0.07362]\n152 random 030140021120025413531223400200032422 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta234 = [0.5, 0.0, 0.0, 0.0, 0.5, 0.0]\n153 random 022432232053401453122503124411423021 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.12934, 0.17639, 0.27301, 0.1412, 0.17947, 0.10059]\n154 random 503340334534055025155210542351404540 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.21829, 0.12187, 0.03847, 0.14306, 0.23396, 0.24435]\n155 random 351313240153324514514414154553121052 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0637, 0.20156, 0.15149, 0.13642, 0.20371, 0.24313]\n156 random 540553342231540414323350225255000554 BAD  period = 2 beta1 = [1, 0, 0, 0, 0, 0] beta2000 = [0.001, 0.0, 0.0, 0.0, 0.999, 0.0]\n157 random 314150320252351114511141113410052541 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.12337, 0.29069, 0.20385, 0.09679, 0.10087, 0.18443]\n158 random 330210143354152142143432420440203020 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.12676, 0.12565, 0.1407, 0.16491, 0.37693, 0.06504]\n159 random 115104414435205434505242522142354030 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n160 random 352014122450112134404213413051323304 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.10495, 0.24672, 0.27458, 0.14614, 0.14494, 0.08266]\n161 random 331140204313435230254021550541104535 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n162 random 030523221541322532255312541223435123 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n163 random 521512035054554244330455312534141140 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.10856, 0.1583, 0.07382, 0.1673, 0.26281, 0.22922]\n164 random 503405402123143234151113514533211224 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.12016, 0.26371, 0.16829, 0.17068, 0.15753, 0.11964]\n165 random 101211230534120235410032320035152531 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.23507, 0.26249, 0.22678, 0.12353, 0.05463, 0.0975]\n166 random 003531241050505034241433342323152211 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.17045, 0.14861, 0.1659, 0.22579, 0.15198, 0.13727]\n167 random 450442324001000011432100540445402230 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n168 random 014552424220343345142332423511222241 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n169 random 400414354012344550242344143313154302 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.11615, 0.21716, 0.07342, 0.20672, 0.2806, 0.10595]\n170 random 032430035412422412345541412313011504 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta293 = [0.0576, 0.25274, 0.22061, 0.15062, 0.18696, 0.13147]\n171 random 515502111524451442123322425330155524 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n172 random 411031540012055332154151012334230322 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0] beta105 = [0.1715, 0.23194, 0.14909, 0.16427, 0.12755, 0.15564]\n173 random 131435413325533505345214151442303421 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.06713, 0.17257, 0.15851, 0.19459, 0.22305, 0.18415]\n174 random 350333440001431214531535322432043145 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.11126, 0.14007, 0.10981, 0.25593, 0.18075, 0.20218]\n175 random 435140422452343030315245531314145003 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.13059, 0.16005, 0.11338, 0.21136, 0.22875, 0.15587]\n176 random 332150211131125113120311342515552422 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n177 random 200334252144100311531552531245152451 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.08199, 0.22806, 0.14048, 0.10389, 0.18412, 0.26145]\n178 random 321353210220250222414110502311453514 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.18635, 0.17036, 0.28785, 0.13105, 0.10056, 0.12384]\n179 random 534304253521205132222505510555102003 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.15438, 0.11102, 0.27683, 0.1464, 0.07866, 0.2327]\n180 random 244300144525440001150340450510312043 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.24365, 0.17621, 0.12506, 0.05183, 0.29846, 0.10479]\n181 random 402404100352435221445055300042100010 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.28014, 0.09558, 0.12235, 0.10536, 0.2984, 0.09816]\n182 random 241152435134250255122520030313300430 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.21578, 0.13959, 0.22995, 0.13736, 0.10732, 0.16999]\n183 random 344324051555134041203452121011414344 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.04816, 0.29466, 0.09913, 0.05357, 0.24036, 0.26413]\n184 random 433235233253004015551450035224521243 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.1431, 0.10366, 0.18122, 0.18486, 0.16021, 0.22695]\n185 random 435301210455330100033405432433525402 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.32699, -0.0, 0.0, 0.25707, 0.41594, 0.0]\n186 random 131004344354353234313404420542254403 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.22497, 0.08956, 0.09784, 0.18917, 0.2977, 0.10077]\n187 random 300301434315415142533251001002335225 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.09795, 0.18118, 0.1853, 0.26537, 0.08527, 0.18493]\n188 random 504524223354230513540523140535044421 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.1268, 0.10987, 0.15655, 0.17147, 0.21239, 0.22291]\n189 random 321240301501224325150301224205202404 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.17524, 0.12535, 0.32743, 0.0905, 0.23019, 0.05129]\n190 random 335050045435145523145402231222254035 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n191 random 234125115125024050300121122311123051 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.15938, 0.28118, 0.21404, 0.10427, 0.07993, 0.16119]\n192 random 052025532415144125552001552034432211 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.05773, 0.16544, 0.29869, 0.09754, 0.20122, 0.17939]\n193 random 503120412230152232455144504045151241 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0] beta105 = [0.14364, 0.19041, 0.1954, 0.09757, 0.18015, 0.19281]\n194 random 511424443231251210023523010055154512 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1] beta105 = [0.11159, 0.23916, 0.17574, 0.12515, 0.15376, 0.19461]\n195 random 111300053212425440250454534010450452 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.23735, 0.19431, 0.13301, 0.07641, 0.16689, 0.19202]\n196 random 210313514245214153432013235351541252 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0] beta105 = [0.05065, 0.2453, 0.16784, 0.20531, 0.16091, 0.16999]\n197 random 311401355042322043553153413425253325 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.08803, 0.14869, 0.12183, 0.30023, 0.07746, 0.26377]\n198 random 030434511101144431045345555340131214 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n199 random 253544405330223204124033252444425332 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0] beta105 = [0.12782, 0.02816, 0.23508, 0.22034, 0.32639, 0.0622]\nGood: 147  Percentage: 74 %\nPeriod 0 : 0\nPeriod 1 : 195\nPeriod 2 : 5\nPeriod 3 : 0"}︡
︠24a523bc-104a-4e2f-8ddd-e25d0dff12f8︠
L=checkgroupoidlist(3,200,arity=1)
︡563e5d4d-9212-4760-9904-166c36d6a037︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/14/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 222221221 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.0, 0.42245, 0.57755]\n1 random 021000001 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.99918, 6e-05, 0.00076]\n2 random 202122102 BAD  period = 1 beta1 = [1, 0, 0] beta2000 = [0.0005, 0.0005, 0.999]\n3 random 101021010 GOOD period = 1 beta1 = [1, 0, 0] beta218 = [0.4491, 0.39493, 0.15597]\n4 random 101212122 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n5 random 221021100 GOOD period = 2 beta1 = [0, 0, 1] beta2000 = [0.32508, 0.3246, 0.35032]\n6 random 220122221 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 1.0, 0.0]\n7 random 120121000 GOOD period = 1 beta1 = [0, 0, 1] beta132 = [0.36603, 0.36603, 0.26795]\n8 random 001210222 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n9 random 122220021 GOOD period = 1 beta1 = [0, 0, 1] beta665 = [0.24904, 0.28197, 0.46899]\n10 random 012002100 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n11 random 222211200 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.0, 0.0, 1.0]\n12 random 210202222 BAD  period = 1 beta1 = [0, 1, 0] beta2000 = [0.0005, 0.0, 0.9995]\n13 random 122102200 GOOD period = 1 beta1 = [0, 0, 1] beta304 = [0.34421, 0.18067, 0.47511]\n14 random 200010210 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.42245, 0.0, 0.57755]\n15 random 021212120 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n16 random 202010202 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n17 random 112111120 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [0.0, 1.0, 0.0]\n18 random 001012110 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n19 random 100110121 BAD  period = 1 beta1 = [1, 0, 0] beta2000 = [0.0005, 0.9995, 0.0]\n20 random 220121011 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.0, 1.0, 0.0]\n21 random 021000002 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n22 random 020210001 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n23 random 121121120 GOOD period = 1 beta1 = [0, 0, 1] beta243 = [0.17157, 0.41421, 0.41421]\n24 random 021211100 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n25 random 012101200 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.5, 0.5, 0.0]\n26 random 210210012 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [0.5, 0.0, 0.5]\n27 random 022011010 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.9995, 0.0, 0.0005]\n28 random 201011210 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.3569, 0.44504, 0.19806]\n29 random 211121010 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.144, 0.54176, 0.31424]\n30 random 102002120 BAD  period = 0 beta1 = [0, 1, 0] beta431 = [NaN, NaN, NaN]\n31 random 010000112 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n32 random 212012210 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n33 random 110201001 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.39661, 0.43204, 0.17135]\n34 random 222220220 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 0.0, 1.0]\n35 random 121002221 GOOD period = 1 beta1 = [0, 0, 1] beta304 = [0.18067, 0.34421, 0.47511]\n36 random 121121210 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.13397, 0.5, 0.36603]\n37 random 010121011 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.0, 1.0, 0.0]\n38 random 110102222 BAD  period = 1 beta1 = [1, 0, 0] beta2000 = [0.00062, 0.0, 0.99938]\n39 random 212202201 GOOD period = 1 beta1 = [0, 0, 1] beta140 = [0.22778, 0.29496, 0.47726]\n40 random 011012120 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.25, 0.5, 0.25]\n41 random 200010112 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.44721, 0.27639, 0.27639]\n42 random 022111121 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.0, 0.9995, 0.0005]\n43 random 002022112 BAD  period = 1 beta1 = [0, 1, 0] beta2000 = [0.0, 0.0005, 0.9995]\n44 random 100202210 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.41594, 0.25707, 0.32699]\n45 random 020102120 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.5, 0.25, 0.25]\n46 random 012211202 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n47 random 111202202 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.0, 0.32759, 0.67241]\n48 random 212011102 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n49 random 202201212 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [0.0, 0.0, 1.0]\n50 random 210010002 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [0.5, 0.0, 0.5]\n51 random 101010021 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.5, 0.5, 0.0]\n52 random 020222120 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n53 random 210222212 BAD  period = 1 beta1 = [1, 0, 0] beta2000 = [0.0005, 0.0, 0.9995]\n54 random 010210212 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n55 random 022221211 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.0, 1.0, 0.0]\n56 random 202210221 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n57 random 200201220 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.42245, 0.0, 0.57755]\n58 random 000000210 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.9995, 0.0, 0.0005]\n\n...\n\n145 random 121000002 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n146 random 221010101 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.34292, 0.40172, 0.25536]\n147 random 121122221 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 1.0, 0.0]\n148 random 011121022 BAD  period = 1 beta1 = [0, 1, 0] beta2000 = [0.0, 0.0005, 0.9995]\n149 random 102102220 BAD  period = 0 beta1 = [1, 0, 0] beta232 = [+infinity, +infinity, -infinity]\n150 random 100002201 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [1.0, 0.0, 0.0]\n151 random 012122020 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n152 random 202211110 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n153 random 101220011 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.00103, 0.99897, 0.0]\n154 random 200120021 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.46945, 0.20265, 0.3279]\n155 random 010001202 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n156 random 001212121 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n157 random 000022121 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.0, 0.0, 1.0]\n158 random 002101010 BAD  period = 1 beta1 = [0, 1, 0] beta2000 = [0.9995, 0.0005, 0.0]\n159 random 002100210 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n160 random 011112012 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n161 random 102011112 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n162 random 101111112 BAD  period = 1 beta1 = [1, 0, 0] beta2000 = [0.0005, 0.9995, 0.0]\n163 random 220211002 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [0.5, 0.0, 0.5]\n164 random 102210211 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.25, 0.5, 0.25]\n165 random 120111021 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n166 random 221100212 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.24512, 0.32472, 0.43016]\n167 random 221202001 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.31982, 0.28384, 0.39634]\n168 random 211201202 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n169 random 022010101 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.5, 0.25, 0.25]\n170 random 112010021 BAD  period = 1 beta1 = [1, 0, 0] beta2000 = [0.0005, 0.9995, -0.0]\n171 random 201101222 GOOD period = 0 beta1 = [1, 0, 0] beta2000 = [0.00318, 0.05483, 0.94199]\n172 random 121112120 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n173 random 222110221 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.17157, 0.41421, 0.41421]\n174 random 122120002 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.33333, 0.16667, 0.5]\n175 random 201122112 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n176 random 202212101 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.23607, 0.38197, 0.38197]\n177 random 111001121 BAD  period = 2 beta1 = [0, 0, 1] beta2000 = [0.57755, 0.42245, 0.0]\n178 random 102200012 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n179 random 110222002 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.38197, 0.23607, 0.38197]\n180 random 210202000 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [1.0, 0.0, 0.0]\n181 random 022111121 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.0, 0.9995, 0.0005]\n182 random 100101022 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n183 random 222010012 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n184 random 000110220 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n185 random 220120012 BAD  period = 1 beta1 = [0, 1, 0] beta2000 = [0.49975, 0.0005, 0.49975]\n186 random 001220210 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.5, 0.20711, 0.29289]\n187 random 111210112 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n188 random 202000200 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 0.0, 1.0]\n189 random 112022102 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n190 random 222112200 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n191 random 122020122 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.00061, 0.00038, 0.999]\n192 random 011111122 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n193 random 202002001 GOOD period = 1 beta1 = [1, 0, 0] beta112 = [0.41421, 0.17157, 0.41421]\n194 random 001210020 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n195 random 110001100 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.57755, 0.42245, 0.0]\n196 random 022211111 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [0.0, 1.0, 0.0]\n197 random 212211200 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 0.0, 1.0]\n198 random 200001201 GOOD period = 1 beta1 = [0, 0, 1] beta271 = [0.44504, 0.19806, 0.3569]\n199 random 020022012 BAD  period = 1 beta1 = [0, 1, 0] beta2000 = [0.0, 0.0005, 0.9995]\nGood: 50  Percentage: 25 %\nPeriod 0 : 4\nPeriod 1 : 164\nPeriod 2 : 32\nPeriod 3 : 0"}︡
︠731cae8c-5b0c-4cee-b3ae-80312a2e0b2d︠
L = groupoids(2)
L2 = checkgroupoidlist(2,L,arity=1)
︡28a3cfe0-0241-4c43-9004-440efd9c819b︡{"stdout": "0\n0 0 0000 BAD  period = 1 beta1 = [1, 0] beta105 = [1.0, 0.0]\n1 1 0001 BAD  period = 1 beta1 = [1, 0] beta105 = [1.0, 0.0]\n2 2 0010 BAD  period = 1 beta1 = [1, 0] beta105 = [1.0, 0.0]\n3 3 0011 BAD  period = 1 beta1 = [0, 1] beta105 = [0.0, 1.0]\n4 4 0100 BAD  period = 1 beta1 = [1, 0] beta105 = [1.0, 0.0]\n5 5 0101 BAD  period = 1 beta1 = [0, 1] beta105 = [0.0, 1.0]\n6 6 0110 BAD  period = 1 beta1 = [1, 0] beta105 = [1.0, 0.0]\n7 8 1000 BAD  period = 2 beta1 = [0, 1] beta2000 = [1.0, 0.0]\n8 10 1010 GOOD period = 2 beta1 = [1, 0] beta2000 = [0.57755, 0.42245]\n9 12 1100 GOOD period = 2 beta1 = [1, 0] beta2000 = [0.57755, 0.42245]\nGood: 2  Percentage: 20 %\nPeriod 0 : 0\nPeriod 1 : 7\nPeriod 2 : 3\nPeriod 3 : 0"}︡
︠820a3039-4be7-40dd-87a1-a8cee969d21b︠
L = groupoids(3)
L3 = checkgroupoidlist(3,L,arity=1)
︡1503eeab-7d47-4037-80ba-bb486d59882e︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/3/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0\n1000\n2000\n3000\n4000\n5000\n6000\n7000\n8000\n9000\n10000\n11000\n12000\n13000\n14000\n15000\n16000\n17000\n18000\n19000\n0 0 000000000 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n1 1 000000001 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n2 2 000000002 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n3 3 000000010 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n4 4 000000011 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n5 5 000000012 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n6 6 000000020 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n7 7 000000021 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n8 8 000000022 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n9 9 000000100 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n10 10 000000101 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n11 11 000000102 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n12 12 000000110 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n13 13 000000111 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n14 14 000000112 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n15 15 000000120 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n16 16 000000121 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n17 17 000000122 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n18 18 000000200 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.9995, 0.0, 0.0005]\n19 19 000000201 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n20 20 000000202 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n21 21 000000210 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n22 22 000000211 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n23 23 000000212 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n24 24 000000220 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.9995, 0.0, 0.0005]\n25 25 000000221 BAD  period = 1 beta1 = [0, 0, 1] beta2000 = [0.9995, 0.0, 0.0005]\n26 26 000000222 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n27 28 000001001 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n28 29 000001002 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [0.0, 0.0, 1.0]\n29 30 000001010 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n30 31 000001011 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n31 32 000001012 BAD  period = 1 beta1 = [0, 1, 0] beta105 = [1.0, 0.0, 0.0]\n32 33 000001020 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n33 34 000001021 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n34 35 000001022 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n35 36 000001100 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n36 37 000001101 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n37 38 000001102 BAD  period = 1 beta1 = [1, 0, 0] beta105 = [1.0, 0.0, 0.0]\n38 39 000001110 BAD  period = 1 beta1 = [0, 0, 1] beta105 = [1.0, 0.0, 0.0]\n\n...\n\n3275 10728 112201100 BAD  period = 0 beta1 = [0, 1, 0] beta2000 = [0.0006, 0.97529, 0.02412]\n3276 10729 112201101 GOOD period = 1 beta1 = [0, 1, 0] beta147 = [0.31767, 0.46557, 0.21676]\n3277 10731 112201110 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.29289, 0.5, 0.20711]\n3278 10734 112201120 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.26947, 0.40157, 0.32896]\n3279 10738 112201201 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.29289, 0.41421, 0.29289]\n3280 10747 112202001 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.33333, 0.33333, 0.33333]\n3281 10755 112202100 GOOD period = 2 beta1 = [0, 0, 1] beta2000 = [0.22264, 0.45802, 0.31934]\n3282 10756 112202101 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.0, 0.99897, 0.00103]\n3283 10758 112202110 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.26947, 0.40157, 0.32896]\n3284 10761 112202120 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.27639, 0.27639, 0.44721]\n3285 10765 112202201 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.24512, 0.32472, 0.43016]\n3286 10855 112220001 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.33333, 0.33333, 0.33333]\n3287 10863 112220100 GOOD period = 1 beta1 = [0, 0, 1] beta109 = [0.33333, 0.33333, 0.33333]\n3288 10864 112220101 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.26746, 0.38692, 0.34563]\n3289 10866 112220110 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.25777, 0.39493, 0.3473]\n3290 10869 112220120 GOOD period = 1 beta1 = [0, 0, 1] beta127 = [0.29289, 0.29289, 0.41421]\n3291 10873 112220201 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.26587, 0.32467, 0.40946]\n3292 11098 120020001 GOOD period = 1 beta1 = [0, 0, 1] beta117 = [0.48803, 0.28823, 0.22374]\n3293 11106 120020100 GOOD period = 1 beta1 = [0, 0, 1] beta336 = [0.45161, 0.31111, 0.23729]\n3294 11107 120020101 GOOD period = 1 beta1 = [0, 0, 1] beta130 = [0.41167, 0.33653, 0.2518]\n3295 11109 120020110 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.39493, 0.3473, 0.25777]\n3296 11112 120020120 GOOD period = 1 beta1 = [0, 0, 1] beta128 = [0.41421, 0.29289, 0.29289]\n3297 11116 120020201 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.41349, 0.27071, 0.3158]\n3298 11341 120120001 GOOD period = 1 beta1 = [1, 0, 0] beta128 = [0.38577, 0.35321, 0.26102]\n3299 11349 120120100 BAD  period = 3 beta1 = [1, 0, 0] beta2000 = [0.0, 1.0, 0.0]\n3300 11350 120120101 GOOD period = 1 beta1 = [0, 1, 0] beta126 = [0.31706, 0.39816, 0.28477]\n3301 11355 120120120 GOOD period = 3 beta1 = [0, 0, 1] beta2000 = [0.38552, 0.42245, 0.19203]\n3302 11359 120120201 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.33333, 0.33333, 0.33333]\n3303 11422 120200001 GOOD period = 1 beta1 = [1, 0, 0] beta109 = [0.46165, 0.27991, 0.25844]\n3304 11430 120200100 GOOD period = 1 beta1 = [1, 0, 0] beta315 = [0.43426, 0.30278, 0.26297]\n3305 11431 120200101 GOOD period = 2 beta1 = [1, 0, 0] beta2000 = [0.5, 0.19098, 0.30902]\n3306 11433 120200110 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.38692, 0.34563, 0.26746]\n3307 11440 120200201 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.38917, 0.26859, 0.34224]\n3308 11449 120201001 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.40946, 0.32467, 0.26587]\n3309 11457 120201100 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.38692, 0.34563, 0.26746]\n3310 11476 120202001 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.41777, 0.27124, 0.31099]\n3311 11484 120202100 GOOD period = 1 beta1 = [0, 1, 0] beta129 = [0.39816, 0.28477, 0.31706]\n3312 11485 120202101 GOOD period = 0 beta1 = [0, 0, 1] beta2000 = [0.34399, 0.31274, 0.34327]\n3313 11487 120202110 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.33333, 0.33333, 0.33333]\n3314 11584 120220001 GOOD period = 1 beta1 = [1, 0, 0] beta108 = [0.42351, 0.27205, 0.30444]\n3315 11592 120220100 BAD  period = 3 beta1 = [0, 0, 1] beta2000 = [1.0, 0.0, 0.0]\n3316 11593 120220101 BAD  period = 2 beta1 = [0, 1, 0] beta2000 = [0.0, 1.0, 0.0]\n3317 11595 120220110 GOOD period = 1 beta1 = [1, 0, 0] beta113 = [0.33333, 0.33333, 0.33333]\n3318 11827 121020001 GOOD period = 1 beta1 = [1, 0, 0] beta128 = [0.41167, 0.33653, 0.2518]\n3319 11835 121020100 GOOD period = 1 beta1 = [1, 0, 0] beta254 = [0.38757, 0.35205, 0.26038]\n3320 11836 121020101 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 0.0, 1.0]\n3321 11838 121020110 GOOD period = 1 beta1 = [1, 0, 0] beta105 = [0.31982, 0.39634, 0.28384]\n3322 12151 121200001 GOOD period = 2 beta1 = [1, 0, 0] beta2000 = [0.5, 0.19098, 0.30902]\n3323 12159 121200100 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [0.0, 1.0, 0.0]\n3324 12205 121202001 GOOD period = 0 beta1 = [0, 0, 1] beta2000 = [0.34399, 0.31274, 0.34327]\n3325 12213 121202100 BAD  period = 2 beta1 = [1, 0, 0] beta2000 = [1.0, 0.0, 0.0]\n3326 12216 121202110 GOOD period = 1 beta1 = [0, 1, 0] beta105 = [0.26859, 0.38917, 0.34224]\n3327 12321 121220100 BAD  period = 3 beta1 = [0, 0, 1] beta2000 = [1.0, 0.0, 0.0]\n3328 12556 122020001 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.41349, 0.27071, 0.3158]\n3329 12567 122020110 GOOD period = 1 beta1 = [0, 0, 1] beta105 = [0.33333, 0.33333, 0.33333]\nGood: 1009  Percentage: 30 %\nPeriod 0 : 50\nPeriod 1 : 2714\nPeriod 2 : 538\nPeriod 3 : 28"}︡
︠6946aa15-4664-4ccb-bc28-bd4691411e35︠
L=checkgroupoidlist(7,200,arity=1)
︡e41a1d91-1ede-4824-9ab5-f5e04df066e4︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/11/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 1061646533645403603316634620421415364012244515532 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.08494, 0.14184, 0.12011, 0.16574, 0.1915, 0.137, 0.15886]\n1 random 3263433603543415456322104616130555311612265453433 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.06261, 0.16687, 0.09455, 0.21341, 0.15431, 0.17625, 0.13199]\n2 random 2623006651552044425225250605405433531405111133152 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.14891, 0.14087, 0.16292, 0.1215, 0.14752, 0.20793, 0.07035]\n3 random 5255662226624336626646236403224341416300433614221 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta497 = [0.0, 0.02547, 0.12006, 0.04181, 0.7022, 0.0, 0.11046]\n4 random 3651635040513403600333145641203254101010602511412 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.18419, 0.20968, 0.0762, 0.15963, 0.13103, 0.13229, 0.10698]\n5 random 0214141033446062244123446145335545224235163014336 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n6 random 3645130364234505020140413032344524235613015140143 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.17065, 0.12323, 0.10545, 0.2687, 0.15166, 0.13035, 0.04996]\n7 random 0111122030662164354463425263632020110415141543364 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.11756, 0.17581, 0.14283, 0.17015, 0.15811, 0.09302, 0.14253]\n8 random 5321125154011043562545056252161121634336650015422 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.10773, 0.18551, 0.13829, 0.1208, 0.11137, 0.2049, 0.1314]\n9 random 6401541441503452142026351663545304452343204404053 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.15977, 0.07668, 0.08238, 0.14838, 0.23884, 0.18223, 0.11172]\n10 random 1443600116223002044402252540143250164651044535461 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.15406, 0.18398, 0.13079, 0.07754, 0.23033, 0.11778, 0.10552]\n11 random 0316162144626354154313664251043000261120461262422 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.14223, 0.18274, 0.17325, 0.11069, 0.21527, 0.04927, 0.12656]\n12 random 5144662256553455423351664463366451634006600255012 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.13936, 0.09102, 0.1229, 0.12357, 0.13312, 0.17612, 0.2139]\n13 random 4045606315636004620452631560515142423510034142625 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.18744, 0.05841, 0.13192, 0.07029, 0.22399, 0.17486, 0.15309]\n14 random 1405641363615035533026620106542204026666443654364 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.15546, 0.1038, 0.09274, 0.14509, 0.18181, 0.09993, 0.22117]\n15 random 0103634455323004300604146403444316662525463623302 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.1046, 0.08062, 0.07452, 0.31706, 0.21592, 0.01763, 0.18966]\n16 random 6443452223401505655466502125631236050513602650055 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.16235, 0.03981, 0.10418, 0.04456, 0.07275, 0.34355, 0.2328]\n17 random 6141133345154244656666653531213420661011413353405 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.05964, 0.24087, 0.08167, 0.14621, 0.19839, 0.14669, 0.12653]\n18 random 2553605210545553552453032302150124433634140343006 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n19 random 1535352050510432051355134634651401440432022015210 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.19654, 0.14959, 0.07881, 0.16349, 0.13335, 0.23021, 0.04801]\n20 random 6211301536542254324655055121130424153562140333353 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.06964, 0.13963, 0.1674, 0.17759, 0.14115, 0.20548, 0.09911]\n21 random 4620115630051364635144106146666000300065606156365 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.1769, 0.13704, 0.0, 0.10856, 0.07048, 0.18406, 0.32295]\n22 random 3155454323654120230316334532043645262045513412343 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta182 = [0.05152, 0.04197, 0.06246, 0.16103, 0.2048, 0.40911, 0.06911]\n23 random 0230231426612556456432635340034021231554450354253 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.1184, 0.08011, 0.15592, 0.16714, 0.21152, 0.18219, 0.08474]\n24 random 6042600503413130145310331412211031410000465441233 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.24748, 0.18358, 0.09894, 0.14573, 0.13603, 0.08455, 0.10368]\n25 random 1621325114502115042200665046552401356503040604410 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.18133, 0.23456, 0.14567, 0.04498, 0.09345, 0.16388, 0.13613]\n26 random 2260453434663424654633552110533031453551521246466 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.07121, 0.13123, 0.10606, 0.17374, 0.16495, 0.1791, 0.17371]\n27 random 4055452142503414256341516623216511563265003256140 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.11823, 0.15454, 0.14706, 0.11718, 0.14217, 0.1887, 0.13211]\n28 random 2336336461016352511413001621463036360453424046622 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.15407, 0.17576, 0.11418, 0.18917, 0.11255, 0.03778, 0.2165]\n29 random 3566235353233421432536105301140315545615224456510 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.09338, 0.15431, 0.13866, 0.1924, 0.09505, 0.22676, 0.09946]\n30 random 1163663120602012214266654143505653163154531530650 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.14647, 0.17028, 0.09267, 0.17167, 0.07275, 0.1495, 0.19665]\n31 random 4523063122214353621124033230203454125151121332043 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.07521, 0.08162, 0.2667, 0.36916, 0.07413, 0.05771, 0.07547]\n32 random 0060561026025636115450142623053432121615540444616 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n33 random 6253605450214033542225442665364310143331203156100 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.124, 0.11451, 0.15512, 0.18673, 0.15018, 0.13991, 0.12955]\n34 random 1322512101062303021414121365652221511034514551010 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.22171, 0.31171, 0.16667, 0.14966, 0.05439, 0.05813, 0.03772]\n35 random 1660644560033062242624461160211561050666351665331 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.17425, 0.19297, 0.04645, 0.11626, 0.11071, 0.12478, 0.23458]\n36 random 4565611550630444523204621013660540326455202441663 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n37 random 3332310130331541235600104426124440651263305231421 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n38 random 6601366666425316413040462533531302043331140344425 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.1293, 0.11464, 0.10652, 0.23584, 0.17862, 0.09563, 0.13944]\n39 random 0110151253364034035631216521515444133204662426513 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.07058, 0.17817, 0.09742, 0.1346, 0.21828, 0.16098, 0.13998]\n40 random 1222521331321645420361150450545252656032134323415 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.09994, 0.173, 0.19886, 0.17739, 0.11099, 0.1797, 0.06012]\n41 random 0301414361656645632643565131342314332415452603411 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.01545, 0.22147, 0.05817, 0.13922, 0.1562, 0.16343, 0.24605]\n42 random 4423341406102242616465241460042262625162230560051 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.17503, 0.12867, 0.17265, 0.05394, 0.16791, 0.06338, 0.2384]\n43 random 2203403142534164646211461661513111341122102132224 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta108 = [0.00616, 0.337, 0.1108, 0.14777, 0.24633, 0.05132, 0.10061]\n44 random 3534431465634604236331250005204531364536312335035 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.17842, 0.10072, 0.07381, 0.25321, 0.13577, 0.15362, 0.10445]\n45 random 4421151616350353614052545161600054250216316240521 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.15027, 0.19315, 0.12451, 0.10044, 0.11649, 0.17036, 0.14479]\n46 random 2611452046356166411250346023222451436600111101446 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.08288, 0.22436, 0.13307, 0.02954, 0.20252, 0.12384, 0.20379]\n47 random 1103222232642202240422410052120262515152651402405 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n48 random 4450600350134336246413611344363533554460254402211 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n49 random 6352463364551461013456644244236134506123333335416 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.01088, 0.14658, 0.09662, 0.2323, 0.25147, 0.14181, 0.12034]\n50 random 6365650042240242661424326442420122303054213505312 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.15732, 0.08057, 0.24035, 0.11259, 0.15221, 0.07295, 0.18401]\n51 random 4604146611321030643653524401620520463146231446200 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.16335, 0.13959, 0.14954, 0.10629, 0.19724, 0.06288, 0.1811]\n52 random 6502623256133240303233265121102046622433156106133 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.14272, 0.12294, 0.19043, 0.22558, 0.0487, 0.10055, 0.16909]\n53 random 5464140336650122643005045560166352000664516355445 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.19052, 0.11974, 0.05999, 0.08057, 0.18861, 0.2194, 0.14117]\n54 random 5224042450410255353561114614136664104066410124026 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.1654, 0.16966, 0.14406, 0.07226, 0.16418, 0.13415, 0.15029]\n55 random 0205542523513541023666364655554506144236150164465 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.03578, 0.16912, 0.06782, 0.11656, 0.1421, 0.26511, 0.20352]\n56 random 5522031535054055300305366063414412460261460664351 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.16931, 0.12816, 0.07597, 0.12863, 0.15992, 0.1752, 0.16281]\n57 random 3356024444526532005566142016500556363140102452036 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.17243, 0.08022, 0.12809, 0.13549, 0.12059, 0.16268, 0.20049]\n58 random 0224202522325661222502320330003256141202303563026 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n\n...\n\n145 random 1363103410161156565604023346456023446062162234635 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n146 random 4006434243243533556013503413242012324516544004024 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.16276, 0.09902, 0.1522, 0.17414, 0.22554, 0.10091, 0.08543]\n147 random 0523240534562146443452044124201362310503660003360 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta137 = [0.15554, 0.09715, 0.16025, 0.19475, 0.21125, 0.07816, 0.10291]\n148 random 1050000124534066301005160511421544366041312206031 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n149 random 3655251111062324456544166312040404504513246102602 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.16179, 0.15069, 0.13712, 0.0886, 0.18129, 0.13354, 0.14698]\n150 random 1201620563321362451535613201320621253256423355414 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.07456, 0.16181, 0.17122, 0.2031, 0.08761, 0.18901, 0.1127]\n151 random 0022664352411624043626466433133626000024255621546 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n152 random 2444064442336322360655330353345513304301260305106 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.21297, 0.05586, 0.10533, 0.2152, 0.13604, 0.16054, 0.11406]\n153 random 6630153604132143135625652533034566432635430156042 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.05305, 0.06612, 0.14425, 0.26337, 0.12112, 0.1897, 0.16239]\n154 random 3650134430524433462023536231254025251401411010466 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.14729, 0.1222, 0.16174, 0.17536, 0.16678, 0.12692, 0.09971]\n155 random 0204150503632152366100214642621316410233004054035 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.28345, 0.13912, 0.1353, 0.1042, 0.10207, 0.13964, 0.09623]\n156 random 2333001663123336064435655406640005336255101262605 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.16488, 0.11813, 0.11115, 0.20327, 0.03558, 0.18163, 0.18536]\n157 random 1530103101002515300626020503234235002604364425546 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n158 random 0564556315342214124206346324221610103103421616042 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.08157, 0.22628, 0.17417, 0.1368, 0.17887, 0.07889, 0.12343]\n159 random 3260332535433654513023255565302250413212300264536 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n160 random 4451331664366565205623252550306200122613611661113 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.07145, 0.19929, 0.14697, 0.12793, 0.04863, 0.14264, 0.26309]\n161 random 5460552245160333641613405052442111521326412125015 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.09473, 0.2387, 0.11938, 0.09312, 0.19832, 0.13877, 0.11699]\n162 random 6545453316125624110113404516103162536266441030012 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.1339, 0.21786, 0.10155, 0.11582, 0.12999, 0.12701, 0.17386]\n163 random 2340205522443224040261215435013643415162644002424 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n164 random 1545022542642216553264633056460021203410060042516 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.19373, 0.12329, 0.18904, 0.06512, 0.16686, 0.13809, 0.12387]\n165 random 0326616552346542130302413213521310663404362213004 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta228 = [0.05621, 0.14417, 0.14816, 0.45786, 0.10198, 0.0418, 0.04981]\n166 random 5411352402536003165554436445134025353316263642322 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.06261, 0.09293, 0.16335, 0.18906, 0.1555, 0.18219, 0.15436]\n167 random 2154006223400653441031100046004345044046544251602 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0] beta105 = [0.30607, 0.06746, 0.13261, 0.03797, 0.22081, 0.14687, 0.0882]\n168 random 6264625125305112131250532434350504335514261645606 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta146 = [0.07248, 0.14753, 0.21636, 0.16624, 0.09898, 0.23663, 0.06177]\n169 random 1322534203255536564023141243506346360354545315634 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.05578, 0.07407, 0.09873, 0.2049, 0.23762, 0.1892, 0.13971]\n170 random 2362405456101362456203616046234463214335606334050 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.18406, 0.05242, 0.14512, 0.14378, 0.15544, 0.10155, 0.21762]\n171 random 3305610213420413100635035020650204236420101251101 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n172 random 1114106412404230604646142416343650056443204664461 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.15784, 0.18932, 0.05434, 0.08997, 0.27154, 0.08755, 0.14945]\n173 random 4303242001231326252261316523544236025400060332145 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.12695, 0.12007, 0.2813, 0.15264, 0.1116, 0.09789, 0.10954]\n174 random 2643614565044445633056324101104223605141460411062 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.1444, 0.15046, 0.12845, 0.08491, 0.21633, 0.09791, 0.17754]\n175 random 4530220663301051533513620131315566350540604250435 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.21103, 0.09235, 0.08929, 0.21266, 0.11628, 0.16899, 0.10939]\n176 random 1652346256260031345534422663160332601365622541533 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.05362, 0.0788, 0.19796, 0.25618, 0.12523, 0.11401, 0.17421]\n177 random 4643001122033403524136313256531565051412323646603 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.09933, 0.11829, 0.10947, 0.28437, 0.08848, 0.08702, 0.21304]\n178 random 6261540612520305563421065046504132234415105666365 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.14602, 0.11028, 0.11667, 0.10662, 0.12454, 0.1845, 0.21138]\n179 random 0201356452111223442055655436552055462144361143546 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.07584, 0.13878, 0.13926, 0.13309, 0.19787, 0.23835, 0.0768]\n180 random 2035412364332341004002160021000246505251064635255 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta116 = [0.28784, 0.04738, 0.17669, 0.09191, 0.30537, 0.05248, 0.03834]\n181 random 2631045465035356216632526041430543113630645425002 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.15348, 0.11206, 0.11983, 0.15382, 0.15333, 0.15891, 0.14856]\n182 random 4326123414400640514022343552403431320102253311620 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.13937, 0.13007, 0.12691, 0.21587, 0.24566, 0.09394, 0.04819]\n183 random 6401643301231064022564066550426411440300461224530 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.17757, 0.13424, 0.12701, 0.10537, 0.20433, 0.07502, 0.17646]\n184 random 2232021460153450504614202054422030132040456460350 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.24849, 0.04159, 0.21114, 0.13181, 0.17156, 0.13821, 0.0572]\n185 random 3351505604414662402320044201033434105555105620555 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.29687, 0.12026, 0.03384, 0.16659, 0.1282, 0.19399, 0.06024]\n186 random 3511213113244235626032136433664345532333255051026 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n187 random 3431331102640606652215635101142121256056263543661 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0] beta105 = [0.11076, 0.22311, 0.09088, 0.11272, 0.08672, 0.11933, 0.25648]\n188 random 3543262543443152423300452266125566565323124432631 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.04387, 0.05617, 0.25651, 0.22498, 0.1258, 0.16013, 0.13254]\n189 random 0631223036043261532554336255563626015542062612656 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.11824, 0.08761, 0.13834, 0.12525, 0.05302, 0.26799, 0.20956]\n190 random 5420313315165126164063315625204516364655611644451 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta2000 = [0.0, 0.9995, 0.0, 0.0, 0.0, 0.0, 0.0005]\n191 random 3654200434106064504000356502500446665324340334414 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta2000 = [0.0, 0.0, 0.0, 0.0, 0.9995, 0.0, 0.0005]\n192 random 1216232123266345310145134512244622425242613145463 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.05039, 0.13854, 0.21958, 0.14939, 0.22949, 0.10288, 0.10973]\n193 random 3342545110030332061602120044432642424611514546146 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0] beta105 = [0.15472, 0.15976, 0.15207, 0.15466, 0.20658, 0.06915, 0.10306]\n194 random 4125001231246503150616153652534025122534262533445 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.07082, 0.13205, 0.18062, 0.16023, 0.10193, 0.22683, 0.12753]\n195 random 4051411402061602002332361643015046120340136446555 BAD  period = 0 beta1 = [1, 0, 0, 0, 0, 0, 0] beta270 = [NaN, NaN, NaN, NaN, NaN, NaN, NaN]\n196 random 3003415500541434146463344555165501003223203116344 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1] beta105 = [0.1454, 0.13591, 0.09253, 0.19813, 0.17868, 0.1918, 0.05755]\n197 random 1451206043315222110300551306336022456123165543264 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.14373, 0.17908, 0.1437, 0.15909, 0.09876, 0.16099, 0.11466]\n198 random 3266665116253252331232534365142345110313000152053 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n199 random 2321044334351366506611552551334431231440663460522 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0] beta105 = [0.08725, 0.15042, 0.1126, 0.18773, 0.16239, 0.16993, 0.12969]\nGood: 155  Percentage: 78 %\nPeriod 0 : 2\nPeriod 1 : 198\nPeriod 2 : 0\nPeriod 3 : 0"}︡
︠012157f9-50f6-47ce-b1bb-e74e3afe1a27︠
L=checkgroupoidlist(8,200,arity=1)
︡4f1a902b-7d34-4eb1-9559-9ea483f12ab7︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/15/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 2755002171020437725055570006112651506475503152571547264674365643 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.1271, 0.09196, 0.12328, 0.07525, 0.09839, 0.23633, 0.10978, 0.13791]\n1 random 0177446671157351607022632524557642526324553507401606144556626632 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.09731, 0.08214, 0.13921, 0.08865, 0.15855, 0.14703, 0.1864, 0.10071]\n2 random 3033705411066570154427201260366201400342032366653467642336144411 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.1639, 0.12748, 0.1105, 0.17021, 0.13768, 0.05116, 0.16248, 0.07659]\n3 random 6112152600155504744551416053733002730133505274446733760641422111 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.17727, 0.17192, 0.087, 0.08201, 0.12694, 0.15843, 0.10736, 0.08907]\n4 random 1402011364113101136033466031162302731406741770635110701565241064 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.18007, 0.26909, 0.08069, 0.12293, 0.15339, 0.0374, 0.11011, 0.04633]\n5 random 6621406515466530575514014353021602513266347461510267241026752772 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.11055, 0.14084, 0.13763, 0.07012, 0.12067, 0.1554, 0.16746, 0.09734]\n6 random 1457072635017674020503034222045110605276300302123270646575574074 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.20173, 0.10143, 0.11852, 0.10579, 0.11828, 0.11607, 0.09192, 0.14627]\n7 random 6077630657172456574651574326646256756300150341635000203627634162 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.18905, 0.07231, 0.06443, 0.14471, 0.08012, 0.14329, 0.23073, 0.07536]\n8 random 7675413127525671730342640254520323760135132042147502554624327363 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.11568, 0.08328, 0.1837, 0.15471, 0.13605, 0.13582, 0.07244, 0.11832]\n9 random 1163363745773355721506560304057437674004131463671607736452547571 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.10055, 0.09187, 0.02293, 0.14312, 0.23452, 0.10904, 0.07133, 0.22664]\n10 random 1217124442261347023261237416756444627105276371730740432770024031 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.11233, 0.13812, 0.1558, 0.08509, 0.20609, 0.03773, 0.09737, 0.16748]\n11 random 0047776300105076115150245063766771364715053774704047566531420647 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n12 random 3731427163553573034572113776633564477055036137711025224570704535 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.10492, 0.14536, 0.05801, 0.20548, 0.01754, 0.21921, 0.07563, 0.17385]\n13 random 2721141777076336722623475205345274053320130137737265621354144536 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.09516, 0.10087, 0.15594, 0.16264, 0.11452, 0.12517, 0.0999, 0.14581]\n14 random 1055723522313006266121562427211557460014236401714026515347153273 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11483, 0.17112, 0.19078, 0.10516, 0.07622, 0.12525, 0.14272, 0.07393]\n15 random 7231452225621322773416563003547337474316040143135451010620452056 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n16 random 0076216337374047642000147132632704517500313607112007334135677121 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.14162, 0.1649, 0.08695, 0.14842, 0.08441, 0.05067, 0.08618, 0.23684]\n17 random 5104621357350444622151401732404130407057162024244171670516477057 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.15073, 0.13784, 0.07982, 0.06941, 0.16787, 0.11691, 0.09453, 0.18289]\n18 random 1766572377704301014420344314072212657030511551667343206306757211 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.13379, 0.16882, 0.10381, 0.13006, 0.10527, 0.07983, 0.10473, 0.17367]\n19 random 0333150113335603712564445742051333531355244526256566672351160271 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n20 random 2706266642676433056744342467672156047637414446154277012556331740 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.09763, 0.08384, 0.10776, 0.11325, 0.17758, 0.08449, 0.17074, 0.16471]\n21 random 7276764627705211462351727054103160272335455633372713233060665601 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.13052, 0.13047, 0.12586, 0.14512, 0.06885, 0.07771, 0.16262, 0.15885]\n22 random 3752222632017564743760067151351374616527512753733410456007163643 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.09544, 0.15008, 0.097, 0.15067, 0.11288, 0.10156, 0.14297, 0.1494]\n23 random 4775657614033544135242675026710273526110255566773333641040653137 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0983, 0.11735, 0.09559, 0.14951, 0.10145, 0.16249, 0.13932, 0.136]\n24 random 4307205172460073077046265063764417041305213073016571712273400267 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.17973, 0.11495, 0.10276, 0.10093, 0.12172, 0.0722, 0.09602, 0.21169]\n25 random 6264517755615043260613210565406557427712155214611463040146074617 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.09826, 0.18514, 0.07042, 0.04274, 0.16082, 0.17368, 0.13542, 0.13353]\n26 random 1520365617114230714151423530700327446765141132173104736226261330 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.11572, 0.21599, 0.10732, 0.13708, 0.10385, 0.09077, 0.10195, 0.12731]\n27 random 5203746755166144232044345574554035634703462253112237443304060016 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.12018, 0.05416, 0.07883, 0.16917, 0.21997, 0.1678, 0.08617, 0.10372]\n28 random 7266050415600450214726314514111261653101151356300420126462165510 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.13186, 0.20728, 0.10725, 0.07247, 0.10614, 0.19117, 0.15867, 0.02516]\n29 random 0472037636452454621711165302730500336163541542527544762213323262 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.09181, 0.13013, 0.16256, 0.15659, 0.12898, 0.12298, 0.11151, 0.09544]\n30 random 6576657176617310000773615356111272032266101270205423534106007550 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.17987, 0.16577, 0.08155, 0.09872, 0.04966, 0.15456, 0.15488, 0.115]\n31 random 5117540216527214200000271163751450765523452517005366353446205704 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.16448, 0.10507, 0.13629, 0.03591, 0.14592, 0.22042, 0.04431, 0.1476]\n32 random 7466146653461661471313621050077235013376005530712277622037612205 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.12351, 0.11543, 0.16961, 0.0837, 0.06486, 0.08162, 0.20314, 0.15813]\n33 random 4515123745635577170054410543062637410634137244224026027253177516 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n34 random 1400700656473113054200673606512430637243343652174347477461320170 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.17625, 0.0861, 0.07244, 0.16874, 0.15264, 0.05567, 0.13471, 0.15344]\n35 random 3212327602207451706740010251300314112702757356250362615761717521 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.1654, 0.17816, 0.17958, 0.07415, 0.02788, 0.10049, 0.11848, 0.15585]\n36 random 7745775051411312351166071407432223402033324074537470633552357402 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.11879, 0.11758, 0.14639, 0.15568, 0.14881, 0.11026, 0.04456, 0.15793]\n37 random 6144405403031321662405122461104736126473364457561152564730316402 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.09586, 0.18079, 0.10129, 0.12179, 0.17307, 0.10775, 0.16359, 0.05586]\n38 random 4136626113311372720512101747637240200137567654462216044305151215 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.09655, 0.20339, 0.15391, 0.14218, 0.07903, 0.09748, 0.10301, 0.12443]\n39 random 1114046370454100723773325436762737026152653335601524650556566016 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n40 random 7111304550465510713353421474307313371535745563024733012164377274 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.10232, 0.12919, 0.06258, 0.18353, 0.14548, 0.16358, 0.0629, 0.15042]\n41 random 7514616426521272275005164123656147255143411064556705222636061543 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.07066, 0.17886, 0.17047, 0.02998, 0.10283, 0.20084, 0.14178, 0.10459]\n42 random 4032031362214164671324040476613560577162205126074560753443170374 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.1483, 0.09191, 0.10001, 0.12308, 0.17289, 0.06571, 0.14932, 0.14879]\n43 random 1047713725042351245061645211354344556673516227733360442114044567 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.06469, 0.10741, 0.11475, 0.12341, 0.19367, 0.13527, 0.15307, 0.10774]\n44 random 3024030137074306315415644170760007435650167022625771532225226376 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.18334, 0.09849, 0.13713, 0.14367, 0.11643, 0.09964, 0.10016, 0.12114]\n45 random 2021211044566042702133521651216727104542043045676376565115553620 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.11611, 0.13154, 0.12955, 0.09175, 0.13841, 0.16992, 0.15116, 0.07156]\n46 random 5266076554530205404720435545670221020374341731671011435717634066 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.14646, 0.11392, 0.09237, 0.1165, 0.12308, 0.14421, 0.13019, 0.13326]\n47 random 1242175653251233643606124470765734013043161444722677166312006103 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.11308, 0.14516, 0.11684, 0.15206, 0.13725, 0.07674, 0.14427, 0.11461]\n48 random 7637366640562476637431144643551357110525646017761042173305352101 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11302, 0.1501, 0.07246, 0.1361, 0.10945, 0.11868, 0.17028, 0.1299]\n49 random 4635716042013024207565021521474113147557504272670126242567410505 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.15139, 0.10595, 0.1431, 0.05028, 0.13504, 0.16837, 0.0929, 0.15298]\n50 random 0152221240764351326345126024047446716500757673462356625617565446 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.07809, 0.07451, 0.12432, 0.07961, 0.15668, 0.18021, 0.18932, 0.11726]\n51 random 3634154543200565225454431111603133002553012763155434403150253147 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.16144, 0.17921, 0.07328, 0.18199, 0.15416, 0.13132, 0.0941, 0.0245]\n52 random 2116671047733037007620776046352767350713270336657102554100162141 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.2019, 0.19658, 0.0901, 0.09157, 0.08176, 0.02741, 0.10885, 0.20183]\n53 random 7266377566027063020443471761542663217000230405464313761170114666 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11163, 0.17587, 0.10049, 0.12693, 0.09623, 0.02862, 0.22058, 0.13964]\n54 random 2411634701145544550266627573644276771024073477720224411323370714 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.09586, 0.13218, 0.14009, 0.0904, 0.18529, 0.0788, 0.11164, 0.16575]\n55 random 6516152475477126462737333640001772423062417605667474524576321123 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 0.5, 0.0, 0.0, 0.0, 0.5, 0.0, 0.0]\n56 random 7010451371015500760733302316532063652500340667654403441236131376 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.1717, 0.12967, 0.08064, 0.18828, 0.09501, 0.09627, 0.1344, 0.10402]\n57 random 2020366221040024104715164373306003607611731166720523613551661620 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.21132, 0.16061, 0.18802, 0.10902, 0.08653, 0.05239, 0.12595, 0.06615]\n58 random 5110357541276404765660657760263007032502663455515320560654065034 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta2000 = [0.00196, 8e-05, 0.0, 1e-05, 8e-05, 0.95457, 0.04321, 8e-05]\n\n...\n\n145 random 4267153260261643577753077443555271676074263233754211616400063145 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.09164, 0.11915, 0.09981, 0.12391, 0.13555, 0.12463, 0.1626, 0.1427]\n146 random 7541314773764562773671553307004231375140177171276473673754033317 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.09919, 0.09811, 0.09401, 0.19817, 0.07003, 0.08637, 0.05196, 0.30216]\n147 random 4641146064351601636246173456556747750220510061427523375157355450 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.1126, 0.14671, 0.08553, 0.07667, 0.14798, 0.17074, 0.14898, 0.1108]\n148 random 3500467576432201071306424236774375366016402756213515731263264633 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.08969, 0.10579, 0.11809, 0.18873, 0.11359, 0.0927, 0.16856, 0.12286]\n149 random 5773314154130324765224742023372733600131530661362636013314717712 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.08913, 0.12836, 0.17218, 0.21014, 0.09901, 0.05383, 0.0966, 0.15075]\n150 random 5170721434737046170010065711104616453301414366300347352430076426 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.1428, 0.16468, 0.04497, 0.16338, 0.14317, 0.07703, 0.12868, 0.13529]\n151 random 4173447302231456776216033007076320743275441572713643644166654626 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.09294, 0.08011, 0.08911, 0.1718, 0.16256, 0.07806, 0.17369, 0.15174]\n152 random 7311562201662271052715534614006261602352671051713546422354777666 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.05107, 0.16822, 0.16507, 0.07658, 0.07592, 0.14642, 0.17678, 0.13994]\n153 random 5554224222406754476274231213516717140407705030431216771115174271 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.08652, 0.17303, 0.14692, 0.07122, 0.16555, 0.10592, 0.05858, 0.19226]\n154 random 0670041360006004303075136653462263513521361726351301103763702077 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.31275, 0.19416, 0.04626, 0.16538, 0.0116, 0.00903, 0.22552, 0.0353]\n155 random 4042377247504174346156276011434123117153453536157142304676353600 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.10979, 0.16932, 0.07038, 0.16273, 0.16691, 0.10805, 0.08776, 0.12505]\n156 random 2641374641233074677716650460310663632771474265221121731720306520 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n157 random 6727104212126727277547633040111077261323017273726011410352073211 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.12806, 0.17341, 0.22581, 0.10004, 0.03809, 0.0533, 0.0415, 0.23978]\n158 random 0707677532446203651417743503337672550050445160231441120776663443 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.12362, 0.09201, 0.05633, 0.20146, 0.12512, 0.09914, 0.13731, 0.16501]\n159 random 6317174307336746744530435570351213674256143300137624150046516203 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.13308, 0.13176, 0.06076, 0.18091, 0.122, 0.11773, 0.12356, 0.13021]\n160 random 5663201654737346272042673075156360143576572225522470237524710020 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n161 random 1142251407176236132607510006077021450535531252055165101737743523 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n162 random 1461532531114044757524546347412567303113215175122307002645033615 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.08104, 0.25915, 0.04989, 0.17328, 0.15815, 0.12371, 0.04916, 0.10563]\n163 random 1252126324330726760770465357224171656770220752430545062641213330 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.14148, 0.08799, 0.17232, 0.11799, 0.10155, 0.11136, 0.12944, 0.13789]\n164 random 4463340012571612206563777065356117441310403361613365273316577142 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.10023, 0.16371, 0.08878, 0.1671, 0.09141, 0.11173, 0.14269, 0.13434]\n165 random 3376064241625576524500344735063211111111461100424767575675577362 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0823, 0.16233, 0.10074, 0.08062, 0.1089, 0.14928, 0.16262, 0.15321]\n166 random 7565761010767760424465557144727267173034707701155145704332464773 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.09437, 0.06446, 0.07224, 0.15267, 0.17642, 0.10087, 0.09862, 0.24034]\n167 random 6320451216701161677251522364751032477335465215247061101221735507 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta2000 = [0.0, 0.0, 0.0005, 0.0, 0.0, 0.0, 0.0, 0.9995]\n168 random 4370366555450150536147366333765704325727026343542526301030325501 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.12973, 0.07291, 0.09108, 0.22667, 0.05277, 0.1719, 0.18762, 0.06731]\n169 random 6124177537174367107221167076023030736145215205501077405047474600 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.1944, 0.13239, 0.06188, 0.08613, 0.13586, 0.0985, 0.10731, 0.18353]\n170 random 7725462062566731607065614071510500240250655360144357115201367407 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.17556, 0.12047, 0.10766, 0.06159, 0.09999, 0.14666, 0.16163, 0.12645]\n171 random 1431563436406430332642202561505034111662264323770744475542571553 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n172 random 6221663401334715745527203211571021063303555712124741445603354224 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n173 random 2701677473330635644226262422561165166314506773240247051764661631 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.08337, 0.1467, 0.15884, 0.12152, 0.13971, 0.07099, 0.1758, 0.10306]\n174 random 1112427666231231170147151173625023074061763630330120001660367030 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n175 random 5300042377241730167517013377671340153454644652465165442050755145 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.10339, 0.10509, 0.06159, 0.11756, 0.21956, 0.18683, 0.09958, 0.10642]\n176 random 1172117610156623330653236763550220037431607126613127475352324466 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n177 random 3373535042104475075412027771666207063511441501275374111632375272 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.10585, 0.13441, 0.17805, 0.11999, 0.10282, 0.12449, 0.05643, 0.17797]\n178 random 0314174171245264065427655373661725074736337717006673430266210004 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n179 random 6744572173705132553350741663163114262510501774636163716117115004 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n180 random 4073701227262443542211431343022560700144732377710211110330135050 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.15064, 0.13088, 0.18454, 0.18799, 0.12311, 0.06753, 0.04315, 0.11215]\n181 random 2274753566632166345542436172524710416373401315172220544473376643 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0559, 0.11871, 0.1264, 0.14635, 0.18323, 0.11272, 0.14192, 0.11475]\n182 random 5514726061456635074266425373771745516273075377322676662246731715 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n183 random 1346503442610161441172627414770742763402020243746207300076175451 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.13377, 0.14098, 0.13011, 0.09101, 0.17969, 0.06646, 0.11308, 0.1449]\n184 random 3541600033060133761460431577626612767670350225454605126716465366 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0]\n185 random 1571263424060665217465354360647054131266360530376303462147743374 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.10721, 0.09767, 0.08496, 0.19586, 0.15556, 0.0628, 0.1973, 0.09864]\n186 random 2267014660253716213671270145405217174746603234762531361533125242 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.08304, 0.1772, 0.16763, 0.13409, 0.09045, 0.10599, 0.12604, 0.11555]\n187 random 6567035406267567176415045353001145240257403440064240333671012441 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.20791, 0.07563, 0.07692, 0.10221, 0.21725, 0.12597, 0.10697, 0.08714]\n188 random 2002146413137176427676127764101541214012444455573550434001661701 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.1055, 0.25264, 0.08878, 0.10836, 0.13893, 0.06978, 0.09789, 0.13813]\n189 random 5712144621120732073154642621541456616622623347204461214651130257 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.05481, 0.2083, 0.16901, 0.09243, 0.14699, 0.06672, 0.19188, 0.06985]\n190 random 6561075243562373400754713163625407206446616706351447563630322442 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.09989, 0.06081, 0.10205, 0.13698, 0.16619, 0.12305, 0.19834, 0.1127]\n191 random 7404475014747775005413323344114517527462121237014115140404652113 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.07864, 0.17173, 0.14068, 0.09843, 0.1862, 0.11666, 0.03061, 0.17704]\n192 random 5361650026367406167143505126426774436157205426116770530646437110 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.17669, 0.1336, 0.07648, 0.08727, 0.08797, 0.13128, 0.20365, 0.10306]\n193 random 5313651431716266023644704420631354007606067151604544023352051020 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n194 random 2273470310275503163700275335016564134654327741703647732345162575 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.10122, 0.11325, 0.08088, 0.16767, 0.07454, 0.1994, 0.08534, 0.1777]\n195 random 6653632710270020704150527664320340323452437145277507025705712534 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.12995, 0.07113, 0.15398, 0.13923, 0.13956, 0.12229, 0.07561, 0.16826]\n196 random 1441057365713562731674106416153365074024611433225473467755514400 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.09118, 0.13425, 0.06864, 0.14135, 0.20553, 0.13721, 0.11813, 0.10372]\n197 random 4632746472075650250062256432771064310754014177702150304531754115 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.14887, 0.11904, 0.07332, 0.07248, 0.17883, 0.1377, 0.09944, 0.17031]\n198 random 6205702500636271551141304466444052125030146033252253633177776233 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12507, 0.11023, 0.1393, 0.16041, 0.13355, 0.12384, 0.13877, 0.06882]\n199 random 0227267034414116024375105215660246376102246221562304530417407065 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.18593, 0.09935, 0.18522, 0.08217, 0.15488, 0.07264, 0.11509, 0.10471]\nGood: 161  Percentage: 81 %\nPeriod 0 : 0\nPeriod 1 : 200\nPeriod 2 : 0\nPeriod 3 : 0"}︡
︠51961247-8e39-495d-9f08-bb3ea88a6616︠
L=checkgroupoidlist(9,200,arity=1)
︡fe2755eb-6958-4cb0-a081-a2a2d3594442︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/16/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 603851165768301641828650765376238607032743876582732528818636141822314505068438421 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.0618, 0.17521, 0.08632, 0.10264, 0.08427, 0.08024, 0.18684, 0.08315, 0.13954]\n1 random 764537581112874608046710226553267747576525087651471240757578431220567474714250763 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n2 random 420417626724248174400644315184636707801486285841551584882324187865670476735076877 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.05573, 0.06913, 0.06285, 0.02637, 0.11601, 0.08295, 0.1237, 0.28565, 0.17761]\n3 random 250447314855425616051142767408370483747807681458776207472827167887524605826320753 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.11215, 0.08555, 0.12102, 0.03709, 0.10983, 0.1043, 0.13121, 0.18637, 0.11249]\n4 random 262257470681702767247685336266083557307784131650678766385043181707556742687713210 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.08572, 0.09141, 0.08266, 0.10386, 0.08072, 0.11155, 0.15205, 0.19711, 0.09492]\n5 random 414864375867553476724685070624733663113315215048324023111881107217318352336638830 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.06564, 0.1377, 0.08305, 0.19487, 0.07476, 0.07685, 0.14801, 0.11212, 0.107]\n6 random 710028400454537087756253037050747815741378348058531426144147805838423804513521126 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.14443, 0.10106, 0.09332, 0.11458, 0.12134, 0.13151, 0.03851, 0.13627, 0.11898]\n7 random 563805416241000723538717888822221738217037321283328175474044732678437665754347108 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.08351, 0.08913, 0.13173, 0.14236, 0.09732, 0.07944, 0.06052, 0.13589, 0.1801]\n8 random 010805511038731173266013755523354470752260224378488037322546650341013287007001170 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n9 random 865115614031306218628343320516806162460737105532310182460128013884843221030376567 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.12066, 0.17795, 0.09547, 0.19685, 0.04525, 0.07475, 0.14981, 0.02934, 0.10991]\n10 random 786752403483248487766227385774633863456648152502452183111503887181885138376855081 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n11 random 146002262836473264245655267531273560502654744531354718151152186234005470330581442 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06941, 0.11031, 0.11845, 0.14501, 0.14869, 0.20246, 0.09894, 0.08238, 0.02436]\n12 random 870461057870413731488231821080840047164347457447568434144757235643041310574025085 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]\n13 random 467145503640805451121364106228007226736022541310520121788560250570852267714183321 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.14963, 0.13996, 0.14369, 0.06845, 0.11086, 0.12659, 0.1072, 0.09061, 0.06301]\n14 random 641023174441826812633750153885471073463184054443075335222323017785772046732667575 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.07686, 0.09435, 0.09276, 0.12786, 0.14238, 0.12413, 0.07441, 0.18825, 0.07901]\n15 random 271118785304031880640146435447557848712545447173465355825211032274338613813757088 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.05966, 0.12724, 0.03107, 0.11239, 0.11311, 0.19844, 0.03615, 0.15734, 0.1646]\n16 random 657720288075234235482662314845004078326761587026786180305473451423155547085280158 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.1481, 0.07539, 0.10473, 0.0769, 0.10027, 0.1353, 0.09352, 0.10101, 0.16478]\n17 random 670534517185852555040832265074102486522624852013057218040313855253186801062103762 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.20427, 0.09381, 0.13827, 0.0924, 0.08517, 0.14743, 0.08998, 0.0721, 0.07658]\n18 random 571266404573836533774688010120676131278570130222385676568084268023731056314683763 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12143, 0.10571, 0.10806, 0.12483, 0.0702, 0.0953, 0.16608, 0.11024, 0.09815]\n19 random 837526274403081788235443076020480357814141658148775533845863326242205565436304148 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.10192, 0.08696, 0.07525, 0.11624, 0.17995, 0.09237, 0.09151, 0.07744, 0.17836]\n20 random 616125588026653052355434823735771436236745362854452227777342286872231082237132138 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.01745, 0.06068, 0.18045, 0.15846, 0.1619, 0.15246, 0.08714, 0.12744, 0.05404]\n21 random 832846224330511274017316443217753844215517617128818300421112225182335822685732187 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.05706, 0.17359, 0.13332, 0.14994, 0.09627, 0.10141, 0.029, 0.13846, 0.12096]\n22 random 156765114661505544302314073448714168500335364106681102425026637651681177044173105 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n23 random 688833338314143417657465301403425562142772617811431655734651208534331502164460358 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.05708, 0.1623, 0.08774, 0.16654, 0.18764, 0.1094, 0.09922, 0.09285, 0.03723]\n24 random 165024260812553376880562081354666576855016402807378757344878012585202168525722205 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n25 random 468462764283005731035380720824103701322500303248068233785821854611467218676555244 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.14058, 0.07175, 0.12954, 0.11948, 0.12434, 0.10412, 0.10654, 0.08137, 0.12227]\n26 random 843254680543772850617468600306446686606727383656181268002228073025856856672062656 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.24147, 0.00306, 0.13891, 0.10648, 0.03569, 0.02073, 0.31705, 0.03599, 0.10061]\n27 random 738564252775222455735150053520702078570868860401760816614067151435273614242757451 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.12305, 0.10502, 0.10404, 0.06948, 0.10755, 0.16594, 0.11115, 0.14013, 0.07364]\n28 random 521650118500421863513107415251045031018621262683076423181427733335524478024888705 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.14322, 0.16293, 0.11169, 0.10307, 0.07908, 0.14336, 0.07787, 0.05732, 0.12146]\n29 random 068533025523443470187246875311360680525126364414342626761174744650580113704102344 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n30 random 760736482474747810021373641145173181558081805146477484487123358168055263062312768 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.08594, 0.13481, 0.07804, 0.08949, 0.1267, 0.09631, 0.10892, 0.12623, 0.15357]\n31 random 614053684812465006063825512300305744855468121207616433864284553774583441078215850 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n32 random 822285161044607172660883635276554570430447004770502004456787613683644257438200183 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.17562, 0.06335, 0.08272, 0.07462, 0.2326, 0.06922, 0.08321, 0.0748, 0.14386]\n33 random 000043244134612522616341123303608534553611516342385454500065731818172305718671138 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.18726, 0.12667, 0.06642, 0.17538, 0.10177, 0.14226, 0.11428, 0.03193, 0.05403]\n34 random 444566883043741542760258784334443257155884261710871273182001487036213611488000262 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.11427, 0.124, 0.10433, 0.08749, 0.17089, 0.08522, 0.08622, 0.08783, 0.13973]\n35 random 458005221786114880475307847424120626231428680887821277736662363143274380277635644 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.04865, 0.08222, 0.10748, 0.20267, 0.08671, 0.01809, 0.29571, 0.06698, 0.09149]\n36 random 054540467204636380345861700463385267263453070171586668578206317572306642355400222 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n37 random 384751380114458602251712663122848146058652215237805156821808036527243230203787782 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.08512, 0.13649, 0.17864, 0.10278, 0.08006, 0.09731, 0.09247, 0.0996, 0.12753]\n38 random 208405675205013834110655762112473040354728527160414222470757270564236156544202753 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.13698, 0.12296, 0.14583, 0.07494, 0.12466, 0.15969, 0.08853, 0.09564, 0.05077]\n39 random 467156283410464470786738855187856623822414443810858736738881812332752701383705357 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.07188, 0.09483, 0.08824, 0.14758, 0.08746, 0.11449, 0.07832, 0.15351, 0.16369]\n40 random 318376861608764813735703252572840488735823046073167357122883516800514586630186407 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta133 = [0.10054, 0.11605, 0.05531, 0.12093, 0.08278, 0.08907, 0.14212, 0.12046, 0.17273]\n41 random 020720665871462788640638838344465752563622624072613342135773073814668663675133586 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.08492, 0.05144, 0.07181, 0.14659, 0.08383, 0.09314, 0.22503, 0.15587, 0.08738]\n42 random 426405675325158238445106057742755484582536677847041155355645361733035371320301808 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.0863, 0.12449, 0.06417, 0.10714, 0.12835, 0.21692, 0.08032, 0.08934, 0.10297]\n43 random 731476147818136657211852441822107274784233042321178056144381844528004565513183248 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.03684, 0.26504, 0.13344, 0.09876, 0.11281, 0.06641, 0.05003, 0.0791, 0.15756]\n44 random 106840204653288878831185331863157734582448083458658202461117413231810544066477164 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.06627, 0.11807, 0.06103, 0.10395, 0.19937, 0.09039, 0.0925, 0.08974, 0.17869]\n45 random 841678016281041482373112484817101332046832256466738813406524732830224436718671665 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.08817, 0.13803, 0.1299, 0.12051, 0.13895, 0.04223, 0.13371, 0.09466, 0.11384]\n46 random 667441556783245453452818647787300741020121477262710878473620522857222178251000874 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.07415, 0.085, 0.17619, 0.03078, 0.11103, 0.10506, 0.03558, 0.28125, 0.10096]\n47 random 670071831746652036754125438264213182365134722231730150506262757116423161778666520 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.08619, 0.14942, 0.13224, 0.11364, 0.09971, 0.11244, 0.15736, 0.11309, 0.03591]\n48 random 365623666483846544825532178877683127032731757560516813647610022472510056666656855 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.13171, 0.08702, 0.09327, 0.07969, 0.06532, 0.12098, 0.23086, 0.08697, 0.10419]\n49 random 757387584308684156287634120857646400785853578782785823624443028617113852083674107 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.10646, 0.07519, 0.10225, 0.09815, 0.09885, 0.10253, 0.09241, 0.16039, 0.16377]\n50 random 277440810377403041282801712174740163783537335055154376163731871048503203066182407 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.18506, 0.1189, 0.06809, 0.13599, 0.1441, 0.07626, 0.04446, 0.16203, 0.06511]\n51 random 828828478725286740345666601478653200211156262427542267872764510424256746542188461 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.03897, 0.07944, 0.19403, 0.00885, 0.14566, 0.14551, 0.22591, 0.10611, 0.05552]\n52 random 432782271367512522632885186686454073742057504567840084566606743455245400732206176 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.13714, 0.04405, 0.12757, 0.03532, 0.15776, 0.15634, 0.11081, 0.13837, 0.09263]\n53 random 727603570553755684706301170737202120643517823751011545182282064821383245200882282 BAD  period = 0 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta362 = [NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN]\n54 random 463776156820012542731570187143222887677425106347763116327126808228660851604705026 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.11727, 0.12807, 0.14039, 0.07513, 0.07328, 0.0763, 0.13105, 0.13467, 0.12384]\n55 random 772304222371231587483535883842854780253701710006111668341538783330524720027106402 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.14411, 0.09396, 0.16396, 0.15728, 0.08189, 0.08636, 0.03769, 0.10408, 0.13066]\n56 random 202783347180267387741848377324080807140883435723428615570142721304513350484568658 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.10767, 0.07465, 0.07608, 0.11969, 0.11905, 0.1343, 0.04645, 0.13285, 0.18927]\n57 random 032602174065167410001253206625430548112476157675537065408668733307445761288800566 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.1729, 0.11531, 0.07735, 0.09769, 0.1128, 0.09469, 0.15927, 0.12522, 0.04477]\n58 random 406780311825630585840605632734174533376065332604738354676430154087101515037638242 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.13378, 0.11975, 0.04332, 0.17941, 0.103, 0.11116, 0.10323, 0.12006, 0.0863]\n\n...\n\n145 random 330172310528630288241403522637236374767482156566663583572551365185236752600044151 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.05741, 0.09086, 0.14563, 0.17026, 0.07115, 0.15541, 0.16785, 0.0885, 0.05294]\n146 random 050410143128524280275210776514576251673875162130435707541807818356330631706727800 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.16384, 0.13459, 0.08403, 0.11239, 0.0958, 0.15603, 0.0736, 0.11902, 0.06072]\n147 random 844412026543605587653080718581338268151862645315362085754431123120384080180188148 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n148 random 161637776836034450878483321340754261834047618501026073320026748550848547054613682 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.12622, 0.08894, 0.07973, 0.11779, 0.13, 0.08755, 0.12923, 0.11555, 0.12499]\n149 random 436065850023217000001053106768840017078387735646153765206308552566317408088725272 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.19091, 0.05463, 0.07402, 0.09375, 0.06814, 0.16792, 0.13026, 0.12383, 0.09653]\n150 random 142703063440883704808411616048673177456560643771826457755588622444623020722487058 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.13441, 0.07649, 0.11577, 0.06601, 0.14267, 0.08129, 0.14308, 0.11784, 0.12244]\n151 random 407386755207048265311668620372153413356322418426128823221420686315816362325480637 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.0782, 0.13724, 0.17805, 0.09917, 0.08604, 0.07261, 0.19003, 0.074, 0.08466]\n152 random 246658031701824482185856480407453625765138580753054673842233851037520727837036112 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.11683, 0.08815, 0.11116, 0.12349, 0.09352, 0.12871, 0.08917, 0.11908, 0.1299]\n153 random 153860815655412416524627220003104268133568331447101636217086017240884778251307050 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.13499, 0.14996, 0.11906, 0.09473, 0.11024, 0.1172, 0.11496, 0.07532, 0.08354]\n154 random 218782670654612524806318201182014715810378356634568417470512361112267645688007788 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n155 random 465657733604615336718122353401282086550484305784288203462243813662235208234788603 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.08077, 0.08283, 0.16549, 0.15959, 0.12123, 0.08136, 0.10795, 0.05801, 0.14277]\n156 random 221777654616671006174643772436305545888373216246230467338181241030400244181672683 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n157 random 670864157840045023715448282154675584261085150261843832845631414014413162077067312 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.11118, 0.14548, 0.09553, 0.07411, 0.16632, 0.10239, 0.1092, 0.08808, 0.10771]\n158 random 712653244141475665883332583551488481012001177266427046342418277500378825457116056 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0904, 0.13723, 0.11212, 0.07739, 0.12199, 0.12446, 0.10811, 0.11972, 0.10858]\n159 random 077704700620262806801858727067018118725056135877042025565204448217643586063523371 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.22854, 0.06424, 0.11401, 0.06134, 0.06531, 0.08754, 0.0816, 0.17554, 0.12188]\n160 random 065086337688744612425143686677214432018615862335303111572258843382685515105434203 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.05701, 0.12379, 0.13518, 0.13587, 0.1249, 0.11878, 0.10941, 0.07253, 0.12254]\n161 random 105451553210306564111307071846614134731884747283168733274735171853087406821587361 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.08498, 0.15378, 0.04884, 0.13554, 0.12757, 0.09653, 0.10294, 0.12748, 0.12234]\n162 random 558308185717183171336388458836454165151438476751072743463565658637043816508377377 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.06739, 0.11751, 0.0214, 0.15515, 0.13269, 0.1463, 0.10389, 0.15169, 0.10397]\n163 random 846521003046615864575287731208408353535638885254262830784341267502610000275806061 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.14644, 0.08451, 0.13261, 0.08621, 0.08048, 0.144, 0.11041, 0.08627, 0.12907]\n164 random 518014057468657051220432775330523333624476633221004670054622277037438752483321477 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.1526, 0.05036, 0.13357, 0.17172, 0.14307, 0.10697, 0.08356, 0.1165, 0.04167]\n165 random 143526546867340430040270110078744671207852576726532022173462880764706741726357055 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.13242, 0.08274, 0.11557, 0.06718, 0.14769, 0.09281, 0.11137, 0.18821, 0.06201]\n166 random 052255646782150412230032887446410734574582201841378247626816226106648376167844345 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.5, 0.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n167 random 163100350010053281753050725131866031376626126847327305768650263080703555420018216 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.20939, 0.18725, 0.0742, 0.14069, 0.03115, 0.07644, 0.12196, 0.07852, 0.0804]\n168 random 631686004015020062461360036470778550160512722847563428131262616326300876678676477 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n169 random 330827623322250787204842233561037370646767470684442038706267446602234863828715051 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.09871, 0.04035, 0.14984, 0.13319, 0.15802, 0.03177, 0.19027, 0.11365, 0.0842]\n170 random 240471234382736305888820336310156336714455302231114765283774133344547257860027406 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.09109, 0.13163, 0.08648, 0.17541, 0.13733, 0.10821, 0.08149, 0.11137, 0.07698]\n171 random 552828761866126614160132715816716062872010252258144474830565105454507377820365771 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.1008, 0.12313, 0.11677, 0.05266, 0.10584, 0.13885, 0.13619, 0.13943, 0.08634]\n172 random 571032351606504278707515441864504714701761280143576605843513765868118314455175212 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.1154, 0.15284, 0.06769, 0.07633, 0.11968, 0.13359, 0.12175, 0.1226, 0.09013]\n173 random 540510373043543104622305213454082807582038223313604656284575680014638857257846831 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.14877, 0.05136, 0.11853, 0.15292, 0.1147, 0.14251, 0.10537, 0.05636, 0.10949]\n174 random 778060126634436261576667016400500863573751063674473470505722516181318333245281156 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12998, 0.12347, 0.08171, 0.1197, 0.0879, 0.11222, 0.15026, 0.12985, 0.06492]\n175 random 143016520166802860758233844643575056865033551608486083426364316417822613114427057 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.14148, 0.10543, 0.06969, 0.13092, 0.12325, 0.11017, 0.16965, 0.05026, 0.09917]\n176 random 287080216533684588716645071007188505842854426621231621550075317746081721631001613 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.12638, 0.15754, 0.09659, 0.09493, 0.07012, 0.13154, 0.12487, 0.08631, 0.11173]\n177 random 411017205454551348404411150804327655561377554032121850456786523743721240655887572 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.08341, 0.20051, 0.09105, 0.0797, 0.14217, 0.19599, 0.05042, 0.11573, 0.04103]\n178 random 126876326154521751047526222163352278445037218761863113378871147628884617226228288 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.00481, 0.11947, 0.23755, 0.03911, 0.09385, 0.07197, 0.09901, 0.1487, 0.18551]\n179 random 831278711701573420602078230177080367042714578555085821162061284664136372433671407 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n180 random 627088447603608488252128448152383763027813276128875133515407815564403428584354213 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.0456, 0.07972, 0.08821, 0.28304, 0.10234, 0.08881, 0.06943, 0.06258, 0.18027]\n181 random 562176312508863060156244066557101708220355306681444810333344374215056256243652247 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11525, 0.10639, 0.10627, 0.14556, 0.13975, 0.13596, 0.1218, 0.06136, 0.06767]\n182 random 411463450182247165166423645721161253152178274647032140775745275481636814165745382 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.02141, 0.12791, 0.15525, 0.07661, 0.145, 0.1257, 0.13586, 0.13222, 0.08004]\n183 random 418112274400782144040784048122741581252350505544352058403158350051713001318651235 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.1232, 0.1188, 0.1562, 0.04073, 0.18538, 0.20487, 0.00608, 0.01538, 0.14935]\n184 random 242786542752118472864874054062411880733808465883088237416082438660305870808466317 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.13368, 0.05972, 0.09739, 0.08029, 0.12974, 0.06441, 0.10919, 0.12495, 0.20064]\n185 random 524027515764005744318116001765778661171072756036020341600852133571826523306357137 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.15862, 0.11972, 0.09552, 0.10095, 0.06844, 0.14099, 0.12809, 0.1375, 0.05017]\n186 random 845800501133340478815423821664004017145202261648503638523112101018761512728044378 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.14545, 0.17117, 0.10483, 0.09486, 0.16085, 0.07136, 0.06229, 0.05417, 0.13502]\n187 random 612563531082348150135402161856572566314310135317361734534375553846663201871555008 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.05673, 0.15112, 0.08055, 0.19975, 0.06537, 0.20502, 0.09442, 0.06717, 0.07987]\n188 random 786280065622358513005615816341662408120120026812373254381358625402653806817733844 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0]\n189 random 870850448425801514180586653358156377166488141220770603083880668611736063315228025 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.12934, 0.11277, 0.08937, 0.11679, 0.07215, 0.11882, 0.10405, 0.07588, 0.18083]\n190 random 514241664763067374781335534382084735586302056451665045864256634214324762377500324 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.11305, 0.05258, 0.10067, 0.13276, 0.14161, 0.15252, 0.17431, 0.07426, 0.05823]\n191 random 441361617182860344353115821722770223875251367281138114207051021515885648483773431 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.04339, 0.17906, 0.11801, 0.12411, 0.10731, 0.09213, 0.04447, 0.12297, 0.16854]\n192 random 723288337850835844278251210745214687875148882840120157803244151685111680035335406 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.12116, 0.11321, 0.10052, 0.10278, 0.10257, 0.12769, 0.05322, 0.10963, 0.16922]\n193 random 667285120333731545341516635823236765017266631433478656064355322830084153618322803 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.04922, 0.07725, 0.13424, 0.21852, 0.08367, 0.12693, 0.16807, 0.08207, 0.06004]\n194 random 661372833606703623073085526546008230837612445223218514313142526350628287166681078 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.12406, 0.09664, 0.14622, 0.16081, 0.04292, 0.12133, 0.17115, 0.04996, 0.08691]\n195 random 717540330261250887473351430844514542213465041856314170864474455061228772515332217 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.08128, 0.16067, 0.09534, 0.08914, 0.16745, 0.14238, 0.09837, 0.0942, 0.07117]\n196 random 548182746703106666101680016530545706487120562317066577447626378352144870258746052 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.11637, 0.07629, 0.09818, 0.06662, 0.12997, 0.10345, 0.15415, 0.15682, 0.09817]\n197 random 611624536016611533078404774140055047633387801360468061477076172732261538214517325 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.13288, 0.15672, 0.05575, 0.13475, 0.10196, 0.09708, 0.14978, 0.12731, 0.04377]\n198 random 644271463587416303130767224868065517067781587543165064154205821308448324087225218 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.09777, 0.10793, 0.1151, 0.0871, 0.13523, 0.09646, 0.10751, 0.11922, 0.13368]\n199 random 738055601661116761404256887474241644516881415132807640442437427634626643273344300 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06003, 0.15782, 0.07174, 0.10379, 0.21028, 0.06395, 0.14639, 0.09191, 0.09408]\nGood: 173  Percentage: 87 %\nPeriod 0 : 1\nPeriod 1 : 199\nPeriod 2 : 0\nPeriod 3 : 0"}︡
︠fad35e72-478d-4b58-9192-8bb9d7630faf︠
L=checkgroupoidlist(10,200,arity=1)
︡ff83a1f1-34af-4d39-92a0-4000a38e1c33︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/jipsen/13/cells/17/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "0 random 7040747942579943607348659500956185540162451194742187421258880940471776237245359647154452016301114029 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n1 random 5755119293736523792544604894143832301553830272784699216567834018196665608451980697938958164943082872 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.0705, 0.0945, 0.09726, 0.12242, 0.08971, 0.11043, 0.11163, 0.07407, 0.11422, 0.11526]\n2 random 4519614665021812309543713396581864126134806788089221869913414883461410888445934616148586341689522597 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.05755, 0.15734, 0.08024, 0.10385, 0.11647, 0.07378, 0.11555, 0.02946, 0.16122, 0.10454]\n3 random 0519049991146266770501962973649031195990886059132661627610213198605142448914301361349970696371359908 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.10643, 0.18101, 0.05664, 0.08587, 0.08783, 0.09189, 0.12725, 0.06553, 0.05906, 0.13848]\n4 random 1220816509030359535630863864609877566932396103771662646039883719165814842491631866667713785096006146 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.07853, 0.11109, 0.03792, 0.11831, 0.06315, 0.11142, 0.22208, 0.08401, 0.08343, 0.09005]\n5 random 9129061347361787559819986876920591762317559609884549285364575218544680643718744531515360767867286401 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06483, 0.08345, 0.04359, 0.07786, 0.13243, 0.15341, 0.13063, 0.10766, 0.13226, 0.07387]\n6 random 4652210681327109837332701156501109250694187529042090624696662167711260669185230577660278194499938838 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.11448, 0.14033, 0.12295, 0.07996, 0.05034, 0.06832, 0.15433, 0.10306, 0.08078, 0.08546]\n7 random 5806637673188138383961529418809470297291429908370747872416141412823713524303740845287051393148728282 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.09702, 0.10909, 0.11549, 0.11271, 0.09847, 0.05818, 0.04825, 0.10665, 0.15941, 0.09474]\n8 random 6260176740963944810680005813728152056057673417557491499210875508016539670528675485984838245052802913 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.11716, 0.09264, 0.0796, 0.05816, 0.09246, 0.12996, 0.10217, 0.10964, 0.13937, 0.07883]\n9 random 9962280386460067535112157615157318752942030114210766215248222392265062404456558894258463218852826290 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.09092, 0.1369, 0.19128, 0.05246, 0.07574, 0.13026, 0.16092, 0.04577, 0.05365, 0.06211]\n10 random 8536053354485774307193530048745210217492393728669308818286392270825988674262807568379154652838397078 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.09561, 0.05523, 0.10342, 0.12125, 0.08248, 0.10034, 0.09673, 0.1249, 0.13758, 0.08245]\n11 random 7658792129698462590259083695572844773595473286113693611777814997276020830420695440510704809351824431 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0991, 0.09667, 0.09878, 0.08161, 0.10987, 0.09828, 0.09258, 0.11554, 0.08637, 0.1212]\n12 random 7459204627689687523030286335790944573018862499938180127093416230248070730713670004874480448527109375 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.17323, 0.05014, 0.08339, 0.10611, 0.10067, 0.05271, 0.08983, 0.17799, 0.09687, 0.06906]\n13 random 3297078733406794263302985798825673871267811832042810262819687655491601810550365117212530359983035838 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.09441, 0.1182, 0.09253, 0.13228, 0.0311, 0.10458, 0.12428, 0.11945, 0.10955, 0.07361]\n14 random 0376632619833103637430282823865717570134561555379936683678204439655696071598498875808485168178477790 BAD  period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n15 random 9033086108567644771851105670402159367565063573534168130274097170032468525863070755545564328385518543 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.13605, 0.06845, 0.06825, 0.13322, 0.08162, 0.15167, 0.12615, 0.11699, 0.07486, 0.04274]\n16 random 4012539520227574651273307933563943392966286494844166210783373244466590308292222863142569457941318310 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n17 random 9939719045408160042858533159218648714331747638997652552326807763512602643997155768753302522182589582 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.07093, 0.10483, 0.11562, 0.13487, 0.06659, 0.15042, 0.07698, 0.08107, 0.12966, 0.06903]\n18 random 3088852526637573222733651290637432377494724959068000859071711783677388674971717150860243439988976240 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.08301, 0.08811, 0.09854, 0.12152, 0.09497, 0.06743, 0.0927, 0.16644, 0.09791, 0.08939]\n19 random 0587993607503481876895956960183013411990950917049320579494404260156622129091868169437707710092749291 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.18031, 0.11787, 0.07969, 0.05248, 0.07038, 0.07711, 0.08539, 0.09646, 0.08032, 0.15999]\n20 random 1344027768076302115877152819955540399058818218803555100744386646422792280450854698863602611224470402 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12128, 0.10924, 0.11044, 0.06807, 0.10465, 0.10013, 0.10323, 0.08593, 0.13011, 0.06691]\n21 random 7510532288314884489286719745443795756838196946700484970954333704239461303099448246165344000275290569 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12361, 0.0553, 0.07349, 0.11185, 0.14824, 0.10244, 0.07527, 0.08675, 0.10062, 0.12242]\n22 random 1983487860500316485166882227550958916042868982165638686564702594085229759612806218750250765859504239 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.08345, 0.03941, 0.17548, 0.02659, 0.04459, 0.15935, 0.1414, 0.11334, 0.14917, 0.06722]\n23 random 2371926004240972474898038057653562019330254811191653780924943868806048787296626885275197155087788869 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.10384, 0.08872, 0.09268, 0.05495, 0.08823, 0.09559, 0.11922, 0.10433, 0.15195, 0.1005]\n24 random 0441691287222659006359786342875581959383494401504301840425883775045848120170507404759980967179631312 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.16069, 0.09922, 0.08288, 0.07542, 0.13775, 0.09633, 0.07098, 0.0952, 0.0846, 0.09694]\n25 random 2691252072118575125488625506276986467492363476988737261747028417943240492420618396939534012840226564 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.071, 0.07415, 0.15739, 0.08003, 0.12476, 0.07061, 0.12885, 0.09727, 0.09731, 0.09863]\n26 random 2425787190194033250301143726560908300883040688611787569115488763366060621508523039385680826236417516 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.14482, 0.08624, 0.08335, 0.11282, 0.05002, 0.07764, 0.14361, 0.06548, 0.1746, 0.0614]\n27 random 0234695824773433331819240856080387976809250354493718190372080516693912260529761559725095781423349065 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.13151, 0.0839, 0.10677, 0.12029, 0.08931, 0.10102, 0.07028, 0.08787, 0.09761, 0.11143]\n28 random 2387107440434938036011911268725715051745898136535003249738234044234704747706550313357663429550281247 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.11483, 0.0932, 0.06843, 0.14139, 0.12111, 0.12721, 0.05974, 0.14674, 0.07702, 0.05033]\n29 random 4299782221033826082214233193142137387771603425278772453832776621043884057777120507196453987337960209 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta110 = [0.03735, 0.06208, 0.19886, 0.21522, 0.03967, 0.04064, 0.00822, 0.31322, 0.05148, 0.03325]\n30 random 6592962308274706301098564756233562814747405054288627161080089234807436294636159681921292614518125518 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.09994, 0.11282, 0.12733, 0.07339, 0.09839, 0.10476, 0.11721, 0.07166, 0.10593, 0.08858]\n31 random 4000194392101688919833383386783535998688845850971559515542561425566606779593045183272099770269016285 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.10696, 0.09015, 0.06939, 0.07584, 0.06285, 0.15771, 0.11649, 0.06641, 0.12305, 0.13113]\n32 random 2750184458791082546493171845612510211656939886404267098259793250291494277968912233961244253567383268 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.05167, 0.12227, 0.12787, 0.08356, 0.10759, 0.10429, 0.10351, 0.07588, 0.10432, 0.11904]\n33 random 0607456660727234152200685122637911694055041378974347724621133560044194949467377698835437438119247383 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.11162, 0.0951, 0.0799, 0.11647, 0.14355, 0.06354, 0.1187, 0.15118, 0.03726, 0.08268]\n34 random 9932827483913523935399787590661214956438147303456176315210148963792541736664396528455420998076362804 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.05267, 0.10182, 0.0938, 0.14851, 0.11813, 0.10378, 0.12624, 0.0725, 0.06859, 0.11396]\n35 random 7715763038493116688965980803541856855066772776207467078895526235170761710544202690376028336956362213 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.14635, 0.06371, 0.09138, 0.09335, 0.03988, 0.12398, 0.16048, 0.1455, 0.08422, 0.05115]\n36 random 9898773169518314938510729336885931468515082706415032204176746050341737931606374916595745711936579362 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.08424, 0.13184, 0.0414, 0.1306, 0.08557, 0.10634, 0.11603, 0.11429, 0.07125, 0.11845]\n37 random 5672549571225669126577247046075673898706086275054763277813093572958486193387915787971087598151708531 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.07304, 0.111, 0.07571, 0.09461, 0.04403, 0.13624, 0.09047, 0.17658, 0.09297, 0.10537]\n38 random 1198412596868637551823183726881271995710830418289286574079234321514041541043666897541772791115725391 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.05194, 0.15148, 0.09392, 0.0969, 0.09295, 0.10348, 0.11019, 0.12326, 0.10382, 0.07207]\n39 random 8326418718473564024729966220242121370643934563406210549704668557683228087073400935868106346223860819 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.10158, 0.05836, 0.16898, 0.10586, 0.11432, 0.06971, 0.14541, 0.05673, 0.11294, 0.06612]\n40 random 6965277928355686164147882324545988930688381407547999446078089679531187853863528927667925939705286715 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.05747, 0.06725, 0.07811, 0.08498, 0.06878, 0.11695, 0.10441, 0.11981, 0.16931, 0.13294]\n41 random 6378800824715966665452043421471691517369935358184748426841019921460660263718279790321332632944902931 BAD  period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n42 random 4056075273896858891474582821756774691710082043472309671047571560000925985071657614077999613564419413 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12867, 0.10544, 0.05095, 0.06752, 0.11637, 0.10659, 0.0816, 0.15197, 0.0777, 0.1132]\n43 random 1491422333758947941459965380966921257794112046219685171433323104899652389852673279430529764491241873 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.04498, 0.11759, 0.14159, 0.08275, 0.15514, 0.07849, 0.0964, 0.05536, 0.06868, 0.15902]\n44 random 3677559723978220977603223631096408954792320879833835550783708017668731118766960622530909085866162553 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.10433, 0.06863, 0.08486, 0.11417, 0.02393, 0.09769, 0.14095, 0.15193, 0.10741, 0.1061]\n45 random 5910047282077424271782091670267263684973669029584245814816051084928212612609710916437921755949892024 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.13921, 0.13933, 0.18175, 0.0, 0.07812, 0.0605, 0.08803, 0.13123, 0.0939, 0.08793]\n46 random 8550810788562179520909770850841705526776734544143508997058892149034659307599124664752034322714946231 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.11983, 0.06667, 0.09771, 0.07512, 0.13691, 0.10733, 0.05581, 0.12473, 0.11028, 0.10561]\n47 random 4954065073346521766642440208939675040654991149263742039272306506833909251449407302977678675902403489 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.15416, 0.04685, 0.07722, 0.0933, 0.222, 0.07062, 0.07604, 0.0737, 0.02933, 0.15677]\n48 random 2769596832430247331267924616624585234662290055989539508493869901100477063989445659237672006973238264 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.1143, 0.05169, 0.13874, 0.08328, 0.10152, 0.07925, 0.14848, 0.08254, 0.07063, 0.12959]\n49 random 4880446664652868431642263465310970289969775854868711900049931107440794311257128255632537832901656394 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.08865, 0.09186, 0.07873, 0.08493, 0.14285, 0.09777, 0.13033, 0.08538, 0.10669, 0.09281]\n50 random 0783285988620606887038050010605467513056161746453991479582663895796402664843985150316360652295712682 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n51 random 8576265884638182509333524545968649434857270392748594572818406536598242923420104001442299411612547140 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0789, 0.05816, 0.16138, 0.07243, 0.17758, 0.14849, 0.05514, 0.05555, 0.09872, 0.09366]\n52 random 9841836817332851532556434202878164579791083859428060380812282708035750918164409338561270745494849209 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.09961, 0.09244, 0.10823, 0.09748, 0.10282, 0.09582, 0.06147, 0.0857, 0.16864, 0.0878]\n53 random 7903521240330204801309371338647123416656334064834555027762980581983650378163332574554241080139061018 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.12101, 0.12317, 0.10421, 0.20388, 0.07423, 0.08518, 0.08427, 0.09307, 0.06167, 0.0493]\n54 random 3458498313208009323713144545235481657520377878671405484379225271411346610461492628811727625752576655 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06969, 0.12237, 0.10579, 0.09066, 0.13958, 0.10414, 0.08533, 0.13688, 0.09255, 0.05299]\n55 random 5703827650919072477744177823441560533429308506457182875554398668343598108623189144874415453841533665 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.07047, 0.05828, 0.07031, 0.13338, 0.14858, 0.18383, 0.07765, 0.10805, 0.10805, 0.0414]\n56 random 9796389327435610805172931428997481154419717929583898985903465426430963505629588368505452316966495495 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.06076, 0.09103, 0.04059, 0.09439, 0.11824, 0.15827, 0.11277, 0.03734, 0.09524, 0.19137]\n57 random 2703529055954374529375382347012817371935602258126681427126990085086319379032606181618305570135926950 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.10861, 0.11544, 0.12466, 0.13487, 0.0509, 0.11984, 0.06203, 0.10559, 0.07931, 0.09875]\n58 random 7318800884799978200634614028688599498264974104231428313032753769035926719944943640520660804876797016 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.14883, 0.07297, 0.06892, 0.07997, 0.15029, 0.02744, 0.09681, 0.1154, 0.13662, 0.10274]\n\n...\n\n145 random 9415844755488167675835983328263057856161691303933052115976281858279652364315255242523228846537721187 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.01338, 0.10046, 0.19188, 0.09182, 0.03563, 0.17761, 0.07792, 0.07993, 0.15039, 0.08097]\n146 random 3219014757278186819590775392261956357811723056346200713545438085140227648246355650063629361051962455 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.10991, 0.1108, 0.10184, 0.09909, 0.08819, 0.14114, 0.11358, 0.09304, 0.07639, 0.06602]\n147 random 1148871413880982720438672383670941453288898283160142417356341783080044681393750666043268698006348273 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.14955, 0.15113, 0.03659, 0.07604, 0.09203, 0.00815, 0.16165, 0.0788, 0.19146, 0.0546]\n148 random 7254043864488333627334672165778662934873650288925666351519735141201381502709200294180033286796833307 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0923, 0.08865, 0.12234, 0.14183, 0.08622, 0.07913, 0.1207, 0.1029, 0.11, 0.05592]\n149 random 9508073453027748802848669606197321311516177205991490281646536652071922595955590676545320231153295274 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.09139, 0.10122, 0.11351, 0.07749, 0.06991, 0.14655, 0.13352, 0.08826, 0.06929, 0.10884]\n150 random 7997446573376997481014805904614995915144214639222169553984032685049198279497581420271757380210892844 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.08456, 0.1367, 0.10808, 0.07454, 0.15374, 0.05785, 0.05349, 0.08641, 0.09741, 0.14722]\n151 random 2029484614594161501697109518129437483557918209282706728843440667279195351046047889262401434608549799 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.09829, 0.10475, 0.11229, 0.03603, 0.14873, 0.08053, 0.09382, 0.08069, 0.09389, 0.15097]\n152 random 1330162402064180527502640282423296277940257820017738137756351403931248773472375393837438592652030901 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.13207, 0.08319, 0.16633, 0.14136, 0.10302, 0.05024, 0.07294, 0.11986, 0.06228, 0.06871]\n153 random 2130622227966651251692870515133766698644832030968031409786981764990892575090359673706384457632522881 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.09118, 0.08765, 0.12649, 0.09691, 0.06799, 0.08328, 0.13741, 0.09142, 0.11284, 0.10482]\n154 random 8638758023282433569827432409844613534714159430254168868690763847812537607764388671631403104110886462 BAD  period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n155 random 1321177349034322078908414670188089918995862308939401667574187757264296902956757203925842418037679186 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.10202, 0.1011, 0.10367, 0.08603, 0.09536, 0.05817, 0.08142, 0.1102, 0.12377, 0.13827]\n156 random 1414812654393657602411743714884756493044399613393438551858359720367951377656491593336540029944825690 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.05802, 0.08669, 0.04007, 0.15533, 0.15379, 0.12991, 0.13171, 0.06906, 0.06937, 0.10604]\n157 random 4476407584380473321722287434256026178871469325784077399171698815758612076810779829772012120225382614 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.06086, 0.10089, 0.21122, 0.05679, 0.09059, 0.03894, 0.09006, 0.18545, 0.10734, 0.05786]\n158 random 2669568976239954241739083578847866898506177585869637364610568615144662364228579601525625661593191007 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.04223, 0.11938, 0.08306, 0.05165, 0.11606, 0.13403, 0.18939, 0.08367, 0.10452, 0.07601]\n159 random 8071820308233681388277559429186633144713832335387715392238479903761916589055655124476934240179562950 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.06046, 0.10579, 0.07722, 0.1943, 0.08521, 0.0965, 0.09918, 0.09441, 0.08319, 0.10374]\n160 random 2414217914248247748463891256433432410101182745629537483323480742283225610137754913053387397106904537 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.0573, 0.12001, 0.13623, 0.14344, 0.20597, 0.05912, 0.0415, 0.07966, 0.08893, 0.06783]\n161 random 9659412941234762972564827237042661987072790570984637251884261677313488949236503921357378851105569641 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.07145, 0.08889, 0.10465, 0.09379, 0.10288, 0.09123, 0.10905, 0.13172, 0.09555, 0.11079]\n162 random 4750471190042838197115564668327161150438451897577788127317543653146019602831466724637115971679265866 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n163 random 3730878198273638453407880938262835835377190728914090993847171568345119143522081248027100661625745235 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.1014, 0.10936, 0.10469, 0.13638, 0.06937, 0.08646, 0.06732, 0.11227, 0.14265, 0.0701]\n164 random 1797266220626795067213293430060089368270323661690648394256535788996925729598945294189183814389369885 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.08239, 0.07857, 0.1055, 0.09398, 0.0525, 0.09764, 0.1157, 0.06531, 0.16944, 0.13897]\n165 random 0509450620941971299178876526952862329507110215437219269553562599388119907484396911482363380928283781 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06439, 0.15194, 0.11103, 0.07724, 0.0576, 0.09487, 0.06823, 0.06334, 0.14384, 0.16752]\n166 random 4055536405702150776842621791431433139266050685513644505737449502942571503422741719412828763938585928 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11083, 0.09867, 0.10084, 0.09924, 0.14701, 0.1834, 0.0522, 0.11745, 0.05317, 0.03719]\n167 random 2654849974795229933004849615997545556918670386639046930616528550050558787235967373074192252026117128 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.103, 0.08863, 0.09878, 0.06048, 0.07748, 0.14872, 0.12342, 0.08518, 0.08465, 0.12965]\n168 random 4895180736092807070774975648263709684697759765537712402268572790251192709018979450500786640291393708 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.12742, 0.07365, 0.05396, 0.05687, 0.07386, 0.05126, 0.08482, 0.27751, 0.08677, 0.11388]\n169 random 5538675390669020223998937436650906870816542834162250800223657515788588961466041297761675183909460954 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.11626, 0.07094, 0.08576, 0.07556, 0.05438, 0.14052, 0.13965, 0.0925, 0.12502, 0.0994]\n170 random 5774015252036940399035137130193417586702812991474215091208392101175776904541491697410630104759832135 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.13231, 0.14688, 0.0898, 0.09289, 0.09502, 0.11009, 0.04272, 0.10679, 0.04748, 0.13602]\n171 random 7443832228059776033343045053136904452446023565579010190347502966772753815182545152983368376626976648 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.10587, 0.06264, 0.09902, 0.12606, 0.12418, 0.14324, 0.107, 0.10862, 0.06296, 0.06041]\n172 random 0526944970306311037857674472523558065669021284223723190284974138034346370706670918873886528212318986 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.11141, 0.06457, 0.10838, 0.11923, 0.09981, 0.08096, 0.11744, 0.11337, 0.11903, 0.06581]\n173 random 1492992675001638819950025410888111139342363525598413923262872729389541702578467828833685247055065808 GOOD period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0969, 0.09056, 0.1433, 0.09485, 0.07845, 0.10217, 0.05961, 0.06343, 0.18034, 0.09038]\n174 random 9655266942579781430896868354585142309609339337340714118616301974243078128335991449460355048010031395 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11836, 0.11136, 0.06524, 0.15013, 0.10578, 0.09946, 0.09106, 0.06488, 0.08115, 0.11258]\n175 random 9069474242057965785294406469155948798476692063545920920951740476692634841586776446509299682373660719 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.07541, 0.03473, 0.10711, 0.03204, 0.15253, 0.08847, 0.20693, 0.1208, 0.0456, 0.13639]\n176 random 4282035814455568564626922815379243949991114719815258482476218576897172841493968650591200596763374170 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.05406, 0.12494, 0.10369, 0.05104, 0.11156, 0.12767, 0.10946, 0.10352, 0.1102, 0.10387]\n177 random 8962532069851949551432527349501383866825562994061760659741401876316356329865892868657734305020252333 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n178 random 8552294187582138065785750871074615318850882892237367685554281303655377676239894644974793313272737624 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.04711, 0.07408, 0.10338, 0.12389, 0.07939, 0.13439, 0.08983, 0.14105, 0.13024, 0.07665]\n179 random 6191047369746628610000771675786541356100730288488616871019914669777089414177174695937139829905003291 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.11157, 0.16331, 0.04641, 0.06946, 0.09957, 0.03873, 0.14597, 0.15749, 0.06132, 0.10618]\n180 random 1852348908934781303680754327504180015001106995398645636030229679511109404174493679732262554226398713 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.12833, 0.11789, 0.08679, 0.12258, 0.09804, 0.08651, 0.08772, 0.07013, 0.09245, 0.10955]\n181 random 8805075807307498119985236209003731763506957341011264317953542494553998672652511179512848989992862129 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.09882, 0.09588, 0.12087, 0.05275, 0.0503, 0.07776, 0.06137, 0.08044, 0.12191, 0.23988]\n182 random 5733371975984507007209065904338317300394806939390442580120818198337191153581244804434314989604867537 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 1, 0, 0, 0, 0] beta105 = [0.10137, 0.04933, 0.01475, 0.19492, 0.15708, 0.07607, 0.0229, 0.09967, 0.14266, 0.14126]\n183 random 9635666920079703559614674611397115643083897622068308545119519364945429925137882439146341292495229905 GOOD period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06582, 0.11007, 0.09789, 0.09949, 0.11841, 0.13054, 0.11832, 0.05859, 0.04159, 0.15929]\n184 random 0324786545606669212083120756467215738224322630337797551435035850193964287843649593861567869521763993 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.0671, 0.07375, 0.10274, 0.14817, 0.08233, 0.14271, 0.13118, 0.08938, 0.08004, 0.08261]\n185 random 2440786741865830840230584353608669019245080577845281546500903752830298642467129198649213752804733491 GOOD period = 1 beta1 = [0, 0, 1, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.12531, 0.06259, 0.10073, 0.08934, 0.1279, 0.09942, 0.09084, 0.09779, 0.11651, 0.08959]\n186 random 8552023846053637983042704426960832015055542104461917754297327946874036314441932172923792553896667579 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.1195, 0.07136, 0.10965, 0.09906, 0.16582, 0.09692, 0.09974, 0.09382, 0.06168, 0.08244]\n187 random 2002713932266620103402746894998378229641200788156920176022328998291827685834119505442253705881732762 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.11769, 0.07712, 0.17002, 0.07147, 0.07975, 0.06965, 0.08461, 0.10437, 0.10689, 0.11843]\n188 random 4609084844764695000629653966591919443968523648297624074294429144390885424183637172636660668993543092 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.06807, 0.03705, 0.0879, 0.13794, 0.18138, 0.08101, 0.15882, 0.03497, 0.07481, 0.13805]\n189 random 9815258175123079844499101587123213155615861044636933143673652403098196072663494756234212150376807456 BAD  period = 1 beta1 = [0, 0, 0, 0, 1, 0, 0, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0]\n190 random 7729934196507151512220628533299167846978781567351299955557204251117534585027931488099811509412289908 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.10758, 0.11762, 0.13398, 0.04727, 0.05463, 0.13174, 0.04605, 0.08572, 0.12108, 0.15434]\n191 random 4196410666691930680047513906485351657193014986398390032434409542198546882585155103279212875183096290 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.14508, 0.12099, 0.04499, 0.11633, 0.08251, 0.09189, 0.14848, 0.04084, 0.07139, 0.13751]\n192 random 4356307441734761529781570394714810503322037665091071429392076356386922482846667250616167162669830157 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 1, 0, 0, 0] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0]\n193 random 0624937180257352551052450491760808796496152180258214325777520114881634554501293084153504678970715191 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 1, 0, 0] beta105 = [0.10401, 0.13438, 0.1197, 0.06809, 0.11164, 0.18912, 0.0354, 0.11651, 0.0631, 0.05806]\n194 random 1971319490648144382002161467884858397690106935616522543746875888831598617366211733663062098069607123 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.10598, 0.11319, 0.07558, 0.10755, 0.05913, 0.04735, 0.14509, 0.06918, 0.15133, 0.12562]\n195 random 2056413216583439979232265473775071758405548136401457851313180810732243790972099242740581645386064576 GOOD period = 1 beta1 = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0] beta105 = [0.09707, 0.10483, 0.09443, 0.11778, 0.11088, 0.13107, 0.07546, 0.11701, 0.07373, 0.07774]\n196 random 3739185292796790935256047115296069768076286133909750223260756331989945064367329146310629515603959631 GOOD period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 1, 0] beta105 = [0.08872, 0.10287, 0.10082, 0.11367, 0.03106, 0.12925, 0.15977, 0.06259, 0.05347, 0.15778]\n197 random 9005033359806553486870504541417884241621928937937797078386295878316976707662263161638024676888818749 GOOD period = 1 beta1 = [0, 1, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [0.06173, 0.07743, 0.09269, 0.09985, 0.09606, 0.05436, 0.16933, 0.1285, 0.14499, 0.07506]\n198 random 4680607282802704101084783660657456927045898045834857232835192027172137137632529311959865587869753919 BAD  period = 1 beta1 = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1] beta105 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]\n199 random 0523807020969753270191238388537141157897219862874687684824823041136967340685253373136567650191741622 BAD  period = 1 beta1 = [1, 0, 0, 0, 0, 0, 0, 0, 0, 0] beta105 = [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]\nGood: 180  Percentage: 90 %\nPeriod 0 : 0\nPeriod 1 : 200\nPeriod 2 : 0\nPeriod 3 : 0"}︡
︠be906b27-ad69-4e60-bcf0-2d5033479c74︠
# This command is useful if one needs to convert a specific groupoid into input for the Probabilities function.
# This is not the number in the Berman catalog since the value calculated here is distinct for isomorphic copies.
groupoidtoint([[0,0,1],[0,0,0],[0,1,2]])
︡ce5b14bf-3e21-481f-afa7-de7603231653︡{"stdout": "734"}︡
